# Change Log

## [v2.1.12](https://github.com/swift-nav/piksi_tools/tree/v2.1.12) (2018-10-10)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.11...v2.1.12)

**Merged pull requests:**

- don't reuse last\_soln for centering on view [\#908](https://github.com/swift-nav/piksi_tools/pull/908)

## [v2.1.11](https://github.com/swift-nav/piksi_tools/tree/v2.1.11) (2018-10-09)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.10...v2.1.11)

**Merged pull requests:**

- Update view fixes [\#905](https://github.com/swift-nav/piksi_tools/pull/905)
- Fix upgrade fail for -dirty builds \[DEVC-1178\] [\#904](https://github.com/swift-nav/piksi_tools/pull/904)

## [v2.1.10](https://github.com/swift-nav/piksi_tools/tree/v2.1.10) (2018-10-08)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.9...v2.1.10)

**Merged pull requests:**

- Solution and Baseline fixes: [\#903](https://github.com/swift-nav/piksi_tools/pull/903)
- Solution and Baseline fixes: [\#902](https://github.com/swift-nav/piksi_tools/pull/902)
- Bionic support [\#901](https://github.com/swift-nav/piksi_tools/pull/901)
- Fix Velocity view with INS output [\#900](https://github.com/swift-nav/piksi_tools/pull/900)
- Fix Velocity view with INS output [\#899](https://github.com/swift-nav/piksi_tools/pull/899)
- OTA: upgrade daemon related settings [\#890](https://github.com/swift-nav/piksi_tools/pull/890)

## [v2.1.9](https://github.com/swift-nav/piksi_tools/tree/v2.1.9) (2018-10-04)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.8...v2.1.9)

**Merged pull requests:**

- change travis clone depth [\#898](https://github.com/swift-nav/piksi_tools/pull/898)
- Age corr all the time rel [\#897](https://github.com/swift-nav/piksi_tools/pull/897)
- baseline\_view: harmonize table w/o fix [\#896](https://github.com/swift-nav/piksi_tools/pull/896)
- change travis clone depth [\#895](https://github.com/swift-nav/piksi_tools/pull/895)
- Add time propagated as valid for UTC\_TIME [\#894](https://github.com/swift-nav/piksi_tools/pull/894)
- Add time propagated as valid for UTC\_TIME [\#893](https://github.com/swift-nav/piksi_tools/pull/893)
- Fix bugs that came into deg 2 meters drop-down [\#892](https://github.com/swift-nav/piksi_tools/pull/892)
- Fix bugs that came into deg 2 meters drop-down [\#891](https://github.com/swift-nav/piksi_tools/pull/891)

## [v2.1.8](https://github.com/swift-nav/piksi_tools/tree/v2.1.8) (2018-10-02)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.7...v2.1.8)

**Merged pull requests:**

- Fix play/pause on solution and baseline \[DEVC-1146\] [\#889](https://github.com/swift-nav/piksi_tools/pull/889)
- Fix play pause rel [\#888](https://github.com/swift-nav/piksi_tools/pull/888)
- fix typo on baseline tab that prevented clearing [\#887](https://github.com/swift-nav/piksi_tools/pull/887)
- fix typo on baseline tab that prevented clearing [\#886](https://github.com/swift-nav/piksi_tools/pull/886)

## [v2.1.7](https://github.com/swift-nav/piksi_tools/tree/v2.1.7) (2018-09-28)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.6...v2.1.7)

**Merged pull requests:**

- Fix autosurvey bug with dequeue changes \[DEVC-1139\] [\#885](https://github.com/swift-nav/piksi_tools/pull/885)
- Fix autosurvey bug with dequeue changes \[DEVC-1139\] [\#884](https://github.com/swift-nav/piksi_tools/pull/884)

## [v2.1.6](https://github.com/swift-nav/piksi_tools/tree/v2.1.6) (2018-09-26)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.5...v2.1.6)

## [v2.1.5](https://github.com/swift-nav/piksi_tools/tree/v2.1.5) (2018-09-25)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.4...v2.1.5)

## [v2.1.4](https://github.com/swift-nav/piksi_tools/tree/v2.1.4) (2018-09-24)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.0.3...v2.1.4)

## [v2.0.3](https://github.com/swift-nav/piksi_tools/tree/v2.0.3) (2018-09-24)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.3...v2.0.3)

**Merged pull requests:**

- Update fileio tool to allow specifing source and dest directories [\#883](https://github.com/swift-nav/piksi_tools/pull/883)

## [v2.1.3](https://github.com/swift-nav/piksi_tools/tree/v2.1.3) (2018-09-21)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.2...v2.1.3)

## [v2.1.2](https://github.com/swift-nav/piksi_tools/tree/v2.1.2) (2018-09-20)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.1...v2.1.2)

**Merged pull requests:**

- Fix setuptools\_scm for tags that don't conform [\#882](https://github.com/swift-nav/piksi_tools/pull/882)
- Update INS settings documentation [\#881](https://github.com/swift-nav/piksi_tools/pull/881)
- fixup sbp\_msg\_2\_csv.py [\#880](https://github.com/swift-nav/piksi_tools/pull/880)
- Remove default arg for -t [\#879](https://github.com/swift-nav/piksi_tools/pull/879)
- sbp\_msg\_2\_csv.py Remove unneeded print; fix header error [\#877](https://github.com/swift-nav/piksi_tools/pull/877)
- Filter out unknown SBP message warning \[DEVC-1062\] [\#876](https://github.com/swift-nav/piksi_tools/pull/876)
- remove RAW\_IMU msg \(2304\) from UART1:enabled\_sbp\_messages default val [\#875](https://github.com/swift-nav/piksi_tools/pull/875)
- remove RAW\_IMU msg \(2304\) from UART1:enabled\_sbp\_messages default val [\#874](https://github.com/swift-nav/piksi_tools/pull/874)
- Change INS recommended settings and documented default values [\#873](https://github.com/swift-nav/piksi_tools/pull/873)
- Change INS recommended settings and documented default values [\#872](https://github.com/swift-nav/piksi_tools/pull/872)
- Update INS settings documentation for console [\#870](https://github.com/swift-nav/piksi_tools/pull/870)

## [v2.1.1](https://github.com/swift-nav/piksi_tools/tree/v2.1.1) (2018-09-13)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.0...v2.1.1)

## [v2.1.0](https://github.com/swift-nav/piksi_tools/tree/v2.1.0) (2018-09-11)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.1.0-branch...v2.1.0)

## [v2.1.0-branch](https://github.com/swift-nav/piksi_tools/tree/v2.1.0-branch) (2018-09-11)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.0.2...v2.1.0-branch)

**Merged pull requests:**

- Advance hardware info settings in system info group and add product id \[DEVC-472\] [\#869](https://github.com/swift-nav/piksi_tools/pull/869)
- Settings View Updates [\#868](https://github.com/swift-nav/piksi_tools/pull/868)
- Change timeout on soln mode status bar \[DEVC-1061\] [\#867](https://github.com/swift-nav/piksi_tools/pull/867)
- INS warning hint when disabling INS or no settings need changing [\#866](https://github.com/swift-nav/piksi_tools/pull/866)
- Fix indentations in settings.yaml that didn't work on OSX [\#865](https://github.com/swift-nav/piksi_tools/pull/865)
- Console block updates beyond 2.0 if not yet 2.0 \[DEVC-412\] [\#864](https://github.com/swift-nav/piksi_tools/pull/864)
- Open file binary mode [\#863](https://github.com/swift-nav/piksi_tools/pull/863)
- \[DEVC-548\] Remove explicit Klobuchar enable/disable setting [\#862](https://github.com/swift-nav/piksi_tools/pull/862)
- Add useful utility to csvify one message from an SBP data file [\#861](https://github.com/swift-nav/piksi_tools/pull/861)

## [v2.0.2](https://github.com/swift-nav/piksi_tools/tree/v2.0.2) (2018-08-29)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.0.1...v2.0.2)

**Merged pull requests:**

- fixes from release branch [\#859](https://github.com/swift-nav/piksi_tools/pull/859)
- Deque perf fixes crash fixes [\#857](https://github.com/swift-nav/piksi_tools/pull/857)

## [v2.0.1](https://github.com/swift-nav/piksi_tools/tree/v2.0.1) (2018-08-17)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.16...v2.0.1)

**Merged pull requests:**

- fixes for 2.0 release [\#858](https://github.com/swift-nav/piksi_tools/pull/858)

## [v1.5.16](https://github.com/swift-nav/piksi_tools/tree/v1.5.16) (2018-08-15)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.0.0...v1.5.16)

## [v2.0.0](https://github.com/swift-nav/piksi_tools/tree/v2.0.0) (2018-08-15)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.21...v2.0.0)

**Merged pull requests:**

- Remove popup upgrade view [\#855](https://github.com/swift-nav/piksi_tools/pull/855)
- Turn off unknown msg warnings [\#851](https://github.com/swift-nav/piksi_tools/pull/851)
- Add settings documentation entries for the VDF settings. [\#839](https://github.com/swift-nav/piksi_tools/pull/839)

## [v1.6.21](https://github.com/swift-nav/piksi_tools/tree/v1.6.21) (2018-08-14)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.20...v1.6.21)

## [v1.6.20](https://github.com/swift-nav/piksi_tools/tree/v1.6.20) (2018-08-14)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.19...v1.6.20)

## [v1.6.19](https://github.com/swift-nav/piksi_tools/tree/v1.6.19) (2018-08-09)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.18...v1.6.19)

**Merged pull requests:**

- fileio: add progress\_cb reduction factor to reduce load on GUI during… [\#856](https://github.com/swift-nav/piksi_tools/pull/856)
- Let bootload\_v3 script inherit all of serial\_link cmd line args [\#852](https://github.com/swift-nav/piksi_tools/pull/852)
- Update magnetometer scaling for v2.0 fw mag fix [\#850](https://github.com/swift-nav/piksi_tools/pull/850)
- Update magnetometer scaling for v2.0 fw mag fix [\#849](https://github.com/swift-nav/piksi_tools/pull/849)

## [v1.6.18](https://github.com/swift-nav/piksi_tools/tree/v1.6.18) (2018-08-06)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.17...v1.6.18)

**Merged pull requests:**

- Update documentation for RTCM messages supported [\#854](https://github.com/swift-nav/piksi_tools/pull/854)
- Update documentation for RTCM messages supported [\#853](https://github.com/swift-nav/piksi_tools/pull/853)

## [v1.6.17](https://github.com/swift-nav/piksi_tools/tree/v1.6.17) (2018-08-03)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.16...v1.6.17)

**Merged pull requests:**

- \[DEVC-967\] network\_view bug fix: network info list grew and had unnecessary print [\#844](https://github.com/swift-nav/piksi_tools/pull/844)

## [v1.6.16](https://github.com/swift-nav/piksi_tools/tree/v1.6.16) (2018-08-01)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.15...v1.6.16)

## [v1.6.15](https://github.com/swift-nav/piksi_tools/tree/v1.6.15) (2018-07-31)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.14...v1.6.15)

**Merged pull requests:**

- Copy data out of pending to avoid races \[DEVC-975\] \[v1.6\] [\#848](https://github.com/swift-nav/piksi_tools/pull/848)
- Copy data out of pending to avoid races \[DEVC-975\] [\#847](https://github.com/swift-nav/piksi_tools/pull/847)
- settings\_view: make sure a write response doesn't trigger and write\_r… [\#846](https://github.com/swift-nav/piksi_tools/pull/846)
- settings\_view: make sure a write response doesn't trigger and write\_r… [\#845](https://github.com/swift-nav/piksi_tools/pull/845)
- \[DEVC-967\] network\_view bug fix: network info list grew and had unnec… [\#843](https://github.com/swift-nav/piksi_tools/pull/843)
- \[DEVC-963\] obs view resize issue; change look of obs counts and filters [\#842](https://github.com/swift-nav/piksi_tools/pull/842)
- \[DEVC-963\] obs view resize issue; change look of obs counts and filters [\#841](https://github.com/swift-nav/piksi_tools/pull/841)

## [v1.6.14](https://github.com/swift-nav/piksi_tools/tree/v1.6.14) (2018-07-30)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.13...v1.6.14)

**Merged pull requests:**

- \[DEVC-969\] Fix solution\_view scaling issue when switching units [\#840](https://github.com/swift-nav/piksi_tools/pull/840)

## [v1.6.13](https://github.com/swift-nav/piksi_tools/tree/v1.6.13) (2018-07-25)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.12...v1.6.13)

## [v1.6.12](https://github.com/swift-nav/piksi_tools/tree/v1.6.12) (2018-07-20)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.11...v1.6.12)

**Implemented enhancements:**

- Even more signals support from my LSNP PR [\#835](https://github.com/swift-nav/piksi_tools/pull/835)

## [v1.6.11](https://github.com/swift-nav/piksi_tools/tree/v1.6.11) (2018-07-19)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.10...v1.6.11)

**Merged pull requests:**

- Remove semaphore from fileio module \[DEVC-841\] \[v1.6\] [\#838](https://github.com/swift-nav/piksi_tools/pull/838)
- Update view progress documentation \[master\] [\#837](https://github.com/swift-nav/piksi_tools/pull/837)
- Update view progress documentation \[release\] [\#836](https://github.com/swift-nav/piksi_tools/pull/836)
- Remove semaphore from fileio module \[DEVC-841\] [\#834](https://github.com/swift-nav/piksi_tools/pull/834)

## [v1.6.10](https://github.com/swift-nav/piksi_tools/tree/v1.6.10) (2018-07-17)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.9...v1.6.10)

## [v1.6.9](https://github.com/swift-nav/piksi_tools/tree/v1.6.9) (2018-07-16)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.8...v1.6.9)

**Merged pull requests:**

- Add support for enable GAL/BDS setting RELEASE [\#833](https://github.com/swift-nav/piksi_tools/pull/833)
- Support enable GAL/BDS Constellations settings [\#832](https://github.com/swift-nav/piksi_tools/pull/832)

## [v1.6.8](https://github.com/swift-nav/piksi_tools/tree/v1.6.8) (2018-07-12)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.7...v1.6.8)

**Merged pull requests:**

- INS Used flag bug: \(operator precedence\) [\#831](https://github.com/swift-nav/piksi_tools/pull/831)
- INS Used flag bug: \(operator precedence\) [\#830](https://github.com/swift-nav/piksi_tools/pull/830)
- Revert perf release [\#829](https://github.com/swift-nav/piksi_tools/pull/829)
- Added pre-commit to automate linting and avoid travis failures \[v1.6\] [\#828](https://github.com/swift-nav/piksi_tools/pull/828)
- Added pre-commit to automate linting and avoid travis failures [\#827](https://github.com/swift-nav/piksi_tools/pull/827)
- Takes care of two settings that needed to be added \[v1.6\] [\#826](https://github.com/swift-nav/piksi_tools/pull/826)
- Takes care of two settings that needed to be added [\#825](https://github.com/swift-nav/piksi_tools/pull/825)
- Change correction age labels [\#824](https://github.com/swift-nav/piksi_tools/pull/824)
- Change correction age labels [\#823](https://github.com/swift-nav/piksi_tools/pull/823)
- Add locks on data between gui thread and SBP thread [\#822](https://github.com/swift-nav/piksi_tools/pull/822)
- Add locks on data between gui thread and SBP thread [\#821](https://github.com/swift-nav/piksi_tools/pull/821)

## [v1.6.7](https://github.com/swift-nav/piksi_tools/tree/v1.6.7) (2018-07-10)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.6...v1.6.7)

**Merged pull requests:**

- Inertial hints release [\#818](https://github.com/swift-nav/piksi_tools/pull/818)
- Revert "Prevent setuptools and tox from failing on builds with a -bra… [\#817](https://github.com/swift-nav/piksi_tools/pull/817)
- Dzollo/pyqt4 hook [\#816](https://github.com/swift-nav/piksi_tools/pull/816)
- Revert "Prevent setuptools and tox from failing on builds with a -branch in tag" [\#815](https://github.com/swift-nav/piksi_tools/pull/815)
- DEVC-583 Fix odering\_counter race condition bug [\#814](https://github.com/swift-nav/piksi_tools/pull/814)
- Dr inertial release [\#813](https://github.com/swift-nav/piksi_tools/pull/813)
- Dr inertial [\#812](https://github.com/swift-nav/piksi_tools/pull/812)
- Swap base latency with age of corrections on status bar. [\#810](https://github.com/swift-nav/piksi_tools/pull/810)
- Swap base latency with age of corrections on status bar. [\#809](https://github.com/swift-nav/piksi_tools/pull/809)
- Inertial hints \[DEVC-681\] [\#794](https://github.com/swift-nav/piksi_tools/pull/794)

## [v1.6.6](https://github.com/swift-nav/piksi_tools/tree/v1.6.6) (2018-07-09)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.7.dev0...v1.6.6)

## [v1.7.dev0](https://github.com/swift-nav/piksi_tools/tree/v1.7.dev0) (2018-07-09)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.5...v1.7.dev0)

**Merged pull requests:**

- Update UART baud rate documentation [\#811](https://github.com/swift-nav/piksi_tools/pull/811)
- Update CodeFiltered to one column of filters per constellation [\#808](https://github.com/swift-nav/piksi_tools/pull/808)
- Update CodeFiltered to one column of filters per constellation [\#807](https://github.com/swift-nav/piksi_tools/pull/807)
- Gui.invoke later scrub release [\#806](https://github.com/swift-nav/piksi_tools/pull/806)
- Perf improvements: Gui.invoke later scrub / Bulk update ArrayPlotData [\#805](https://github.com/swift-nav/piksi_tools/pull/805)
- travis: remove builds we no longer use [\#803](https://github.com/swift-nav/piksi_tools/pull/803)
- Update UART baud rate documentation [\#796](https://github.com/swift-nav/piksi_tools/pull/796)

## [v1.6.5](https://github.com/swift-nav/piksi_tools/tree/v1.6.5) (2018-07-03)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.4...v1.6.5)

**Merged pull requests:**

- Update SBP [\#801](https://github.com/swift-nav/piksi_tools/pull/801)
- Update SBP [\#800](https://github.com/swift-nav/piksi_tools/pull/800)

## [v1.6.4](https://github.com/swift-nav/piksi_tools/tree/v1.6.4) (2018-06-29)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.3...v1.6.4)

**Merged pull requests:**

- Prevent setuptools and tox from failing on builds with a -branch in tag [\#802](https://github.com/swift-nav/piksi_tools/pull/802)

## [v1.6.3](https://github.com/swift-nav/piksi_tools/tree/v1.6.3) (2018-06-27)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.2...v1.6.3)

## [v1.6.2](https://github.com/swift-nav/piksi_tools/tree/v1.6.2) (2018-06-23)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.1...v1.6.2)

## [v1.6.1](https://github.com/swift-nav/piksi_tools/tree/v1.6.1) (2018-06-22)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.0...v1.6.1)

## [v1.6.0](https://github.com/swift-nav/piksi_tools/tree/v1.6.0) (2018-06-15)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.0-branch...v1.6.0)

## [v1.6.0-branch](https://github.com/swift-nav/piksi_tools/tree/v1.6.0-branch) (2018-06-12)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v2.0.0-branch...v1.6.0-branch)

## [v2.0.0-branch](https://github.com/swift-nav/piksi_tools/tree/v2.0.0-branch) (2018-06-12)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.15...v2.0.0-branch)

**Merged pull requests:**

- Add documentaiton for ntrip.gga\_out\_rev1 [\#798](https://github.com/swift-nav/piksi_tools/pull/798)

## [v1.5.15](https://github.com/swift-nav/piksi_tools/tree/v1.5.15) (2018-06-12)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.14...v1.5.15)

**Closed issues:**

- ModuleNotFoundError: No module named 'handler' [\#797](https://github.com/swift-nav/piksi_tools/issues/797)

## [v1.5.14](https://github.com/swift-nav/piksi_tools/tree/v1.5.14) (2018-05-29)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.13...v1.5.14)

**Merged pull requests:**

- add context to settings [\#792](https://github.com/swift-nav/piksi_tools/pull/792)
- Tcp for settings [\#791](https://github.com/swift-nav/piksi_tools/pull/791)

## [v1.5.13](https://github.com/swift-nav/piksi_tools/tree/v1.5.13) (2018-05-17)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.12...v1.5.13)

**Merged pull requests:**

- Add support for missing signals, order signals consistently [\#790](https://github.com/swift-nav/piksi_tools/pull/790)
- changelog for v1.5.0-release [\#788](https://github.com/swift-nav/piksi_tools/pull/788)
- Update obs drawing logic for tow rollover [\#784](https://github.com/swift-nav/piksi_tools/pull/784)

## [v1.5.12](https://github.com/swift-nav/piksi_tools/tree/v1.5.12) (2018-05-05)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.11...v1.5.12)

**Merged pull requests:**

- Fix obs not drawing \[release\] [\#785](https://github.com/swift-nav/piksi_tools/pull/785)
- Add Galileo to the console [\#770](https://github.com/swift-nav/piksi_tools/pull/770)

## [v1.5.11](https://github.com/swift-nav/piksi_tools/tree/v1.5.11) (2018-05-02)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.10...v1.5.11)

**Merged pull requests:**

- SBAS add line between points for SBAS \(DEVC-632\) \[Release\] [\#783](https://github.com/swift-nav/piksi_tools/pull/783)
- update readme and CHANGELOG [\#782](https://github.com/swift-nav/piksi_tools/pull/782)
- update readme and CHANGELOG [\#781](https://github.com/swift-nav/piksi_tools/pull/781)
- Add line between SBAS points \(DEVC-632\) \[ Master\] [\#779](https://github.com/swift-nav/piksi_tools/pull/779)

## [v1.5.10](https://github.com/swift-nav/piksi_tools/tree/v1.5.10) (2018-04-27)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.9...v1.5.10)

**Merged pull requests:**

- Doc settings v1.5 rel [\#778](https://github.com/swift-nav/piksi_tools/pull/778)
- Doc setting v1.5 [\#777](https://github.com/swift-nav/piksi_tools/pull/777)
- Mark cellmodem.device\_override as advanced \[master\] [\#775](https://github.com/swift-nav/piksi_tools/pull/775)
- Make acq settings behavior more clear \[master\] [\#774](https://github.com/swift-nav/piksi_tools/pull/774)
- Make acquisition settings behavior more clear \[release\] [\#773](https://github.com/swift-nav/piksi_tools/pull/773)
- remove UnicodeDecodeError cryptic messages to fix DEVC-574 [\#771](https://github.com/swift-nav/piksi_tools/pull/771)
- Mark cellmodem.device\_override as advanced [\#769](https://github.com/swift-nav/piksi_tools/pull/769)
- Remove call repeatedly [\#763](https://github.com/swift-nav/piksi_tools/pull/763)

## [v1.5.9](https://github.com/swift-nav/piksi_tools/tree/v1.5.9) (2018-04-26)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.8...v1.5.9)

## [v1.5.8](https://github.com/swift-nav/piksi_tools/tree/v1.5.8) (2018-04-25)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.7...v1.5.8)

**Merged pull requests:**

- update libsbp to 2.3.16 [\#768](https://github.com/swift-nav/piksi_tools/pull/768)
- move cell modem and network widget to network tab [\#767](https://github.com/swift-nav/piksi_tools/pull/767)
- move cell modem and network widget to network tab [\#766](https://github.com/swift-nav/piksi_tools/pull/766)
- Add support for msg\_measurement\_t [\#765](https://github.com/swift-nav/piksi_tools/pull/765)

## [v1.5.7](https://github.com/swift-nav/piksi_tools/tree/v1.5.7) (2018-04-20)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.6...v1.5.7)

**Merged pull requests:**

- Fix zoom\_all with SBAS \(DEVC-524\) [\#760](https://github.com/swift-nav/piksi_tools/pull/760)
- Fix zoom\_all with SBAS \(DEVC-524\) [\#759](https://github.com/swift-nav/piksi_tools/pull/759)

## [v1.5.6](https://github.com/swift-nav/piksi_tools/tree/v1.5.6) (2018-04-18)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.5...v1.5.6)

**Merged pull requests:**

- Silverjam/v1.5/copy syslogs expert [\#762](https://github.com/swift-nav/piksi_tools/pull/762)
- Mark settings for supporting cell modem debugging as advanced [\#761](https://github.com/swift-nav/piksi_tools/pull/761)

## [v1.5.5](https://github.com/swift-nav/piksi_tools/tree/v1.5.5) (2018-04-13)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.4...v1.5.5)

## [v1.5.4](https://github.com/swift-nav/piksi_tools/tree/v1.5.4) (2018-04-10)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.6.dev0...v1.5.4)

**Merged pull requests:**

- update\_view: ensure progress dialog is open b4 using [\#758](https://github.com/swift-nav/piksi_tools/pull/758)
- update\_view: ensure progress dialog is open b4 using [\#757](https://github.com/swift-nav/piksi_tools/pull/757)

## [v1.6.dev0](https://github.com/swift-nav/piksi_tools/tree/v1.6.dev0) (2018-04-05)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.3...v1.6.dev0)

## [v1.5.3](https://github.com/swift-nav/piksi_tools/tree/v1.5.3) (2018-04-04)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.2...v1.5.3)

**Merged pull requests:**

- don't attempt to revert if readonly setting changes [\#754](https://github.com/swift-nav/piksi_tools/pull/754)
- don't attempt to revert if readonly setting changes [\#753](https://github.com/swift-nav/piksi_tools/pull/753)

## [v1.5.2](https://github.com/swift-nav/piksi_tools/tree/v1.5.2) (2018-04-02)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.1...v1.5.2)

**Merged pull requests:**

- Update configure\_udev\_rules.sh [\#752](https://github.com/swift-nav/piksi_tools/pull/752)

## [v1.5.1](https://github.com/swift-nav/piksi_tools/tree/v1.5.1) (2018-03-29)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.0...v1.5.1)

## [v1.5.0](https://github.com/swift-nav/piksi_tools/tree/v1.5.0) (2018-03-23)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.5.0-branch...v1.5.0)

## [v1.5.0-branch](https://github.com/swift-nav/piksi_tools/tree/v1.5.0-branch) (2018-03-23)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.4.6...v1.5.0-branch)

**Closed issues:**

- Support SBP 2.3.13 and SBAS mode flag [\#749](https://github.com/swift-nav/piksi_tools/issues/749)

**Merged pull requests:**

- Implement Cell Status Message in Console [\#751](https://github.com/swift-nav/piksi_tools/pull/751)
- Add SBAS support [\#750](https://github.com/swift-nav/piksi_tools/pull/750)
- Firmware Update -\> Update [\#748](https://github.com/swift-nav/piksi_tools/pull/748)
- Update Changelog v1.4.6 [\#747](https://github.com/swift-nav/piksi_tools/pull/747)
- Allow display of generic meters north and meters east on solution view [\#739](https://github.com/swift-nav/piksi_tools/pull/739)
- Implement Cell Modem Wizard Usage Widget [\#735](https://github.com/swift-nav/piksi_tools/pull/735)

## [v1.4.6](https://github.com/swift-nav/piksi_tools/tree/v1.4.6) (2018-03-20)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.4.5...v1.4.6)

**Merged pull requests:**

- remove unused import [\#746](https://github.com/swift-nav/piksi_tools/pull/746)
- make CallbackPrompt a livemodal window [\#745](https://github.com/swift-nav/piksi_tools/pull/745)

## [v1.4.5](https://github.com/swift-nav/piksi_tools/tree/v1.4.5) (2018-03-19)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.4.4...v1.4.5)

**Merged pull requests:**

- Remove launch Skylark site button, replace with text [\#744](https://github.com/swift-nav/piksi_tools/pull/744)

## [v1.4.4](https://github.com/swift-nav/piksi_tools/tree/v1.4.4) (2018-03-19)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.4.3...v1.4.4)

**Merged pull requests:**

- remove call repeatedly [\#776](https://github.com/swift-nav/piksi_tools/pull/776)
- Dz skylark [\#743](https://github.com/swift-nav/piksi_tools/pull/743)
- Add Skylark tab and show serial number and UUID in main window. [\#740](https://github.com/swift-nav/piksi_tools/pull/740)
- NTRIP and Skylark settings tweaks [\#738](https://github.com/swift-nav/piksi_tools/pull/738)
- Show Klobuchar Disable setting by default. [\#737](https://github.com/swift-nav/piksi_tools/pull/737)

## [v1.4.3](https://github.com/swift-nav/piksi_tools/tree/v1.4.3) (2018-03-09)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.4.2...v1.4.3)

**Merged pull requests:**

- fixes for 1.4 release [\#736](https://github.com/swift-nav/piksi_tools/pull/736)

## [v1.4.2](https://github.com/swift-nav/piksi_tools/tree/v1.4.2) (2018-03-08)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.4.1rc1...v1.4.2)

**Merged pull requests:**

- travis: 'fix' building on macOS [\#734](https://github.com/swift-nav/piksi_tools/pull/734)
- settings.yaml events -\> event [\#732](https://github.com/swift-nav/piksi_tools/pull/732)
- Settings master [\#731](https://github.com/swift-nav/piksi_tools/pull/731)
- use latest pyserial for linux build [\#730](https://github.com/swift-nav/piksi_tools/pull/730)
- Cmd line build [\#728](https://github.com/swift-nav/piksi_tools/pull/728)

## [v1.4.1rc1](https://github.com/swift-nav/piksi_tools/tree/v1.4.1rc1) (2018-02-26)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.4.0...v1.4.1rc1)

**Closed issues:**

- Console: drop-down list for COM ports should refresh on click [\#636](https://github.com/swift-nav/piksi_tools/issues/636)
- Tracking view: fix duration of time, label time scale [\#441](https://github.com/swift-nav/piksi_tools/issues/441)
- import \* should be replaced with explicit imports [\#410](https://github.com/swift-nav/piksi_tools/issues/410)
- Annotate settings [\#384](https://github.com/swift-nav/piksi_tools/issues/384)

**Merged pull requests:**

- don't expand json fields by default [\#727](https://github.com/swift-nav/piksi_tools/pull/727)
- Console RTCM doc \(\#721\) [\#726](https://github.com/swift-nav/piksi_tools/pull/726)
- Only alphanumeric usernames and passwords \[release\] [\#725](https://github.com/swift-nav/piksi_tools/pull/725)
- Only alphanumeric usernames and passwords \[master\] [\#724](https://github.com/swift-nav/piksi_tools/pull/724)
- Fix 'if' syntax in create-dmg-installer.sh [\#723](https://github.com/swift-nav/piksi_tools/pull/723)
- Add ntrip.interval to the list of known settings \[1.4\] [\#722](https://github.com/swift-nav/piksi_tools/pull/722)
- Console RTCM doc [\#721](https://github.com/swift-nav/piksi_tools/pull/721)
- Add ntrip.interval to the list of known settings \[master\] [\#720](https://github.com/swift-nav/piksi_tools/pull/720)
- Fix libdrm symbol errors on Ubuntu 16.04 [\#719](https://github.com/swift-nav/piksi_tools/pull/719)
- Clarify TCP and UDP setting descriptions [\#718](https://github.com/swift-nav/piksi_tools/pull/718)
- Use https index.json link to point to https download link \[Release\] [\#717](https://github.com/swift-nav/piksi_tools/pull/717)
- Use https index.json link to point to https download link [\#715](https://github.com/swift-nav/piksi_tools/pull/715)
- Spectrum analyzer uses FFTMonitor [\#713](https://github.com/swift-nav/piksi_tools/pull/713)
- Change scaling on Magnetomter view [\#710](https://github.com/swift-nav/piksi_tools/pull/710)

## [v1.4.0](https://github.com/swift-nav/piksi_tools/tree/v1.4.0) (2018-02-03)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.4.0-branch...v1.4.0)

## [v1.4.0-branch](https://github.com/swift-nav/piksi_tools/tree/v1.4.0-branch) (2018-02-03)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.8...v1.4.0-branch)

**Closed issues:**

- Linux install error: Failed to execute script console [\#709](https://github.com/swift-nav/piksi_tools/issues/709)

**Merged pull requests:**

- Use multi-line labes for the settings interaction button [\#714](https://github.com/swift-nav/piksi_tools/pull/714)
- Use an old copy of the swig@2 formula for OSX [\#711](https://github.com/swift-nav/piksi_tools/pull/711)
- New sig support \(try 2\) [\#708](https://github.com/swift-nav/piksi_tools/pull/708)
- Upgrade view work [\#707](https://github.com/swift-nav/piksi_tools/pull/707)
- Update sbp to 2.3.4 [\#706](https://github.com/swift-nav/piksi_tools/pull/706)
- settings write response \(with linting\) [\#705](https://github.com/swift-nav/piksi_tools/pull/705)
- label mag measurements in uT [\#703](https://github.com/swift-nav/piksi_tools/pull/703)
- Setting to file gui [\#700](https://github.com/swift-nav/piksi_tools/pull/700)
- update specan for depecrated message [\#699](https://github.com/swift-nav/piksi_tools/pull/699)

## [v1.3.8](https://github.com/swift-nav/piksi_tools/tree/v1.3.8) (2017-12-21)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.7...v1.3.8)

**Merged pull requests:**

- Use requests to download fw [\#698](https://github.com/swift-nav/piksi_tools/pull/698)
- Denniszollo/settings cmd line utility [\#689](https://github.com/swift-nav/piksi_tools/pull/689)

## [v1.3.7](https://github.com/swift-nav/piksi_tools/tree/v1.3.7) (2017-12-21)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.5...v1.3.7)

**Merged pull requests:**

- settings.yaml updated to firmware v1.3.9. [\#697](https://github.com/swift-nav/piksi_tools/pull/697)
- Change mac installer name to \_macos and add text note in .dmg for com… [\#696](https://github.com/swift-nav/piksi_tools/pull/696)
- console.py: Update title for console and select interface [\#695](https://github.com/swift-nav/piksi_tools/pull/695)
- Add changelog and console REAME.txt [\#694](https://github.com/swift-nav/piksi_tools/pull/694)
- allowed firmware upgrade via local file, added time to serial upgrade warning [\#693](https://github.com/swift-nav/piksi_tools/pull/693)
- update sbp version to v2.3.4 [\#692](https://github.com/swift-nav/piksi_tools/pull/692)

## [v1.3.5](https://github.com/swift-nav/piksi_tools/tree/v1.3.5) (2017-12-16)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.4...v1.3.5)

**Merged pull requests:**

- Allow firmware upgrade over SBP by default. [\#688](https://github.com/swift-nav/piksi_tools/pull/688)

## [v1.3.4](https://github.com/swift-nav/piksi_tools/tree/v1.3.4) (2017-12-14)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.3...v1.3.4)

**Merged pull requests:**

- build el cap [\#690](https://github.com/swift-nav/piksi_tools/pull/690)
- baseline\_view: show heading always [\#687](https://github.com/swift-nav/piksi_tools/pull/687)
- Only open a file driver on OSX [\#684](https://github.com/swift-nav/piksi_tools/pull/684)

## [v1.3.3](https://github.com/swift-nav/piksi_tools/tree/v1.3.3) (2017-12-08)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.2...v1.3.3)

**Merged pull requests:**

- Changes to get a release candidate ready [\#683](https://github.com/swift-nav/piksi_tools/pull/683)
- Move some settings to expert [\#681](https://github.com/swift-nav/piksi_tools/pull/681)

## [v1.3.2](https://github.com/swift-nav/piksi_tools/tree/v1.3.2) (2017-12-05)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.0-test...v1.3.2)

**Merged pull requests:**

- remove travis pypi deploy [\#680](https://github.com/swift-nav/piksi_tools/pull/680)
- Mark the NTRIP debug setting as an "expert" value [\#679](https://github.com/swift-nav/piksi_tools/pull/679)

## [v1.3.0-test](https://github.com/swift-nav/piksi_tools/tree/v1.3.0-test) (2017-12-02)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3_devtestest...v1.3.0-test)

## [v1.3_devtestest](https://github.com/swift-nav/piksi_tools/tree/v1.3_devtestest) (2017-12-02)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.dev...v1.3_devtestest)

## [v1.3.dev](https://github.com/swift-nav/piksi_tools/tree/v1.3.dev) (2017-12-02)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.1...v1.3.dev)

## [v1.3.1](https://github.com/swift-nav/piksi_tools/tree/v1.3.1) (2017-11-29)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.3.0...v1.3.1)

**Merged pull requests:**

- Skip deployment cleanup [\#676](https://github.com/swift-nav/piksi_tools/pull/676)

## [v1.3.0](https://github.com/swift-nav/piksi_tools/tree/v1.3.0) (2017-11-29)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.2.3...v1.3.0)

**Merged pull requests:**

- Update default values [\#675](https://github.com/swift-nav/piksi_tools/pull/675)
- updated sbp requirement [\#674](https://github.com/swift-nav/piksi_tools/pull/674)
- update\_view: prevent message about fw upgrade success if device SN ch… [\#672](https://github.com/swift-nav/piksi_tools/pull/672)
- Fix bug in MSI script where '$name'  was shown to user [\#671](https://github.com/swift-nav/piksi_tools/pull/671)
- get actual user when in config script as sudo [\#669](https://github.com/swift-nav/piksi_tools/pull/669)
- Added tab for magnetometer measurements [\#668](https://github.com/swift-nav/piksi_tools/pull/668)
- New sig support [\#667](https://github.com/swift-nav/piksi_tools/pull/667)
- Changelog generator [\#666](https://github.com/swift-nav/piksi_tools/pull/666)

## [v1.2.3](https://github.com/swift-nav/piksi_tools/tree/v1.2.3) (2017-10-25)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.2.2...v1.2.3)

**Merged pull requests:**

- handle WindowsError [\#665](https://github.com/swift-nav/piksi_tools/pull/665)

## [v1.2.2](https://github.com/swift-nav/piksi_tools/tree/v1.2.2) (2017-10-16)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.2.1...v1.2.2)

**Merged pull requests:**

- Add readonly field for every parameter [\#662](https://github.com/swift-nav/piksi_tools/pull/662)
- sbp\_relay\_view: remove running boolean from display [\#661](https://github.com/swift-nav/piksi_tools/pull/661)
- Refresh click [\#660](https://github.com/swift-nav/piksi_tools/pull/660)
- console.py:PortChooser: config enter for ok button [\#659](https://github.com/swift-nav/piksi_tools/pull/659)

## [v1.2.1](https://github.com/swift-nav/piksi_tools/tree/v1.2.1) (2017-10-10)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.2.0...v1.2.1)

**Merged pull requests:**

- Settings confirmation fix [\#658](https://github.com/swift-nav/piksi_tools/pull/658)
- Settings yaml update rtcmv3 [\#657](https://github.com/swift-nav/piksi_tools/pull/657)
- Fix formatting of RST code blocks, purge empty section [\#654](https://github.com/swift-nav/piksi_tools/pull/654)
- Make ext\_events\_1 and ext\_events\_2 expert settings [\#653](https://github.com/swift-nav/piksi_tools/pull/653)

## [v1.2.0](https://github.com/swift-nav/piksi_tools/tree/v1.2.0) (2017-09-26)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.2.0rc3...v1.2.0)

**Closed issues:**

- CSV header tow says msec but actually sec [\#629](https://github.com/swift-nav/piksi_tools/issues/629)

**Merged pull requests:**

- serial\_link: re-add osx fix to use file rather than CDC driver over usb [\#652](https://github.com/swift-nav/piksi_tools/pull/652)
- Update settings.yaml [\#651](https://github.com/swift-nav/piksi_tools/pull/651)

## [v1.2.0rc3](https://github.com/swift-nav/piksi_tools/tree/v1.2.0rc3) (2017-09-16)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.2.0.rc2...v1.2.0rc3)

**Merged pull requests:**

- Settings v1.2 [\#650](https://github.com/swift-nav/piksi_tools/pull/650)
- Rename gpgsa\_msg\_rate to gsa\_msg\_rate [\#649](https://github.com/swift-nav/piksi_tools/pull/649)
- OSX installation fixes [\#648](https://github.com/swift-nav/piksi_tools/pull/648)
- update readme [\#647](https://github.com/swift-nav/piksi_tools/pull/647)
- Correct default values in Piksi console [\#646](https://github.com/swift-nav/piksi_tools/pull/646)
- settings\_view.py: Change revert timeout from 1 second to 5 second [\#645](https://github.com/swift-nav/piksi_tools/pull/645)
- clean up plot\_square\_axes [\#644](https://github.com/swift-nav/piksi_tools/pull/644)
- Make window narrower [\#643](https://github.com/swift-nav/piksi_tools/pull/643)
- observation\_view: restore total obs count [\#642](https://github.com/swift-nav/piksi_tools/pull/642)
- improve console entry point and resource access [\#641](https://github.com/swift-nav/piksi_tools/pull/641)

## [v1.2.0.rc2](https://github.com/swift-nav/piksi_tools/tree/v1.2.0.rc2) (2017-08-30)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.2.0rc2...v1.2.0.rc2)

## [v1.2.0rc2](https://github.com/swift-nav/piksi_tools/tree/v1.2.0rc2) (2017-08-30)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.2.0rc1...v1.2.0rc2)

**Closed issues:**

- Observation signal code 5 \(GPS L1P\) crashes the console [\#635](https://github.com/swift-nav/piksi_tools/issues/635)

**Merged pull requests:**

- tracking view improvements [\#640](https://github.com/swift-nav/piksi_tools/pull/640)
- Remove python console from view [\#639](https://github.com/swift-nav/piksi_tools/pull/639)
- Dynamically refresh serial port list, choose first by default [\#638](https://github.com/swift-nav/piksi_tools/pull/638)
- obs\_view: better handling of 'unsupported' codes [\#637](https://github.com/swift-nav/piksi_tools/pull/637)
- Tow csv log header [\#634](https://github.com/swift-nav/piksi_tools/pull/634)

## [v1.2.0rc1](https://github.com/swift-nav/piksi_tools/tree/v1.2.0rc1) (2017-08-29)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.1.12...v1.2.0rc1)

**Closed issues:**

- console shows PRN+1 instead of PRN [\#615](https://github.com/swift-nav/piksi_tools/issues/615)
- rinex converter support in console [\#395](https://github.com/swift-nav/piksi_tools/issues/395)
- Bar chart for tracking view [\#305](https://github.com/swift-nav/piksi_tools/issues/305)

**Merged pull requests:**

- fix windows build [\#632](https://github.com/swift-nav/piksi_tools/pull/632)
- Windows xp pyserial version and cleanup [\#631](https://github.com/swift-nav/piksi_tools/pull/631)
- imporove packaging situation [\#628](https://github.com/swift-nav/piksi_tools/pull/628)
- force bundle missing libs on linux [\#627](https://github.com/swift-nav/piksi_tools/pull/627)
- fix appveyor build with dev version of enable [\#626](https://github.com/swift-nav/piksi_tools/pull/626)
- Add separate settings for enabling GLO in SPP and RTK filters. [\#625](https://github.com/swift-nav/piksi_tools/pull/625)
- fixed msg parameter for ip status [\#623](https://github.com/swift-nav/piksi_tools/pull/623)
- tracking view and performance improvements [\#622](https://github.com/swift-nav/piksi_tools/pull/622)
- Multiple external events for Duro [\#621](https://github.com/swift-nav/piksi_tools/pull/621)
- Add GLONASS configuration parameters in the console [\#620](https://github.com/swift-nav/piksi_tools/pull/620)
- fix travis osx build [\#619](https://github.com/swift-nav/piksi_tools/pull/619)
- update sbp, yaml [\#618](https://github.com/swift-nav/piksi_tools/pull/618)
- Remove kiwisolver, update deps [\#614](https://github.com/swift-nav/piksi_tools/pull/614)
- appveyor: makensis [\#613](https://github.com/swift-nav/piksi_tools/pull/613)
- remove RELEASE-VERSION from console.spec [\#612](https://github.com/swift-nav/piksi_tools/pull/612)
- linting [\#611](https://github.com/swift-nav/piksi_tools/pull/611)
- Specan master [\#606](https://github.com/swift-nav/piksi_tools/pull/606)

## [v1.1.12](https://github.com/swift-nav/piksi_tools/tree/v1.1.12) (2017-06-23)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.1.G...v1.1.12)

**Merged pull requests:**

- update sbp to 2.2.6 [\#605](https://github.com/swift-nav/piksi_tools/pull/605)
- use setuptools\_scm instead of version.py [\#603](https://github.com/swift-nav/piksi_tools/pull/603)
- travis improvements [\#602](https://github.com/swift-nav/piksi_tools/pull/602)
- bootstrap changes [\#600](https://github.com/swift-nav/piksi_tools/pull/600)
- Appveyor + CI enhancements [\#599](https://github.com/swift-nav/piksi_tools/pull/599)
- Mavlink decode v2 [\#598](https://github.com/swift-nav/piksi_tools/pull/598)
- obs view: shorten labels [\#597](https://github.com/swift-nav/piksi_tools/pull/597)
- Osx bootstrap [\#596](https://github.com/swift-nav/piksi_tools/pull/596)
- add support for old and new tracking msg [\#593](https://github.com/swift-nav/piksi_tools/pull/593)
- Add new dataset to travis [\#592](https://github.com/swift-nav/piksi_tools/pull/592)
- update sbp to 2.2.3 [\#591](https://github.com/swift-nav/piksi_tools/pull/591)
- Fix unset fw download path \[release\] [\#586](https://github.com/swift-nav/piksi_tools/pull/586)
- Fix unset fw download path \[master\] [\#585](https://github.com/swift-nav/piksi_tools/pull/585)
- Add GLO support into Trk and Obs views [\#583](https://github.com/swift-nav/piksi_tools/pull/583)

## [v1.1.G](https://github.com/swift-nav/piksi_tools/tree/v1.1.G) (2017-05-16)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.1.F...v1.1.G)

**Merged pull requests:**

- V1.1.G release notes [\#582](https://github.com/swift-nav/piksi_tools/pull/582)
- Change git command to not have xcode pop-up in OSX \[master\] [\#581](https://github.com/swift-nav/piksi_tools/pull/581)
- Change git command to not have xcode pop-up in OSX [\#580](https://github.com/swift-nav/piksi_tools/pull/580)

## [v1.1.F](https://github.com/swift-nav/piksi_tools/tree/v1.1.F) (2017-05-12)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.1.E...v1.1.F)

**Merged pull requests:**

- Update sbp to 2.2.1 [\#579](https://github.com/swift-nav/piksi_tools/pull/579)
- Update sbp to 2.2.1 [\#578](https://github.com/swift-nav/piksi_tools/pull/578)

## [v1.1.E](https://github.com/swift-nav/piksi_tools/tree/v1.1.E) (2017-05-12)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.1.D...v1.1.E)

**Merged pull requests:**

- Networking hide by default release [\#577](https://github.com/swift-nav/piksi_tools/pull/577)
- Sbp\_relay\_view: remove skylark labels, rename variables, remove visib… [\#576](https://github.com/swift-nav/piksi_tools/pull/576)
- Observation\_view:  Double buffer so that we don't update view inbetween packets [\#575](https://github.com/swift-nav/piksi_tools/pull/575)
- Observation\_view:  Double buffer so that we don't update view inbetween packets [\#574](https://github.com/swift-nav/piksi_tools/pull/574)
- Settings.yml: Remove RTCM 1001, 1003, and 1007 from list of supported… [\#573](https://github.com/swift-nav/piksi_tools/pull/573)
- Settings.yml: Remove RTCM 1001, 1003, and 1007 from list of supported… [\#572](https://github.com/swift-nav/piksi_tools/pull/572)
- settings\_view: ensure same dictionary to play nice with update\_view. [\#571](https://github.com/swift-nav/piksi_tools/pull/571)
- settings\_view: ensure same dictionary to play nice with update\_view. [\#570](https://github.com/swift-nav/piksi_tools/pull/570)
- Traceback forget import rel [\#569](https://github.com/swift-nav/piksi_tools/pull/569)
- Traceback forget import master [\#568](https://github.com/swift-nav/piksi_tools/pull/568)
- settings\_view:  fix blinky settings view with two interfaces connected: [\#567](https://github.com/swift-nav/piksi_tools/pull/567)
- settings\_view:  fix blinky settings view with two interfaces connected: [\#566](https://github.com/swift-nav/piksi_tools/pull/566)

## [v1.1.D](https://github.com/swift-nav/piksi_tools/tree/v1.1.D) (2017-05-02)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.1.C...v1.1.D)

**Merged pull requests:**

- Reduce height and baseline distance precision to mm's [\#565](https://github.com/swift-nav/piksi_tools/pull/565)
- Reduce height and baseline distance precision to mm's [\#564](https://github.com/swift-nav/piksi_tools/pull/564)
- Remove print on receipt of any old settings read response [\#563](https://github.com/swift-nav/piksi_tools/pull/563)
- Add skylark whitelist to minimize up traffic [\#562](https://github.com/swift-nav/piksi_tools/pull/562)
- Add skylark whitelist to minimize up traffic [\#561](https://github.com/swift-nav/piksi_tools/pull/561)
- Remove print on receipt of any old settings read response [\#560](https://github.com/swift-nav/piksi_tools/pull/560)
- settings.yaml: remove 'path:' from notes which was interpreted as a map [\#559](https://github.com/swift-nav/piksi_tools/pull/559)
- settings.yaml: remove 'path:' from first line of setting note [\#558](https://github.com/swift-nav/piksi_tools/pull/558)
- Settings docs 1.1 master [\#557](https://github.com/swift-nav/piksi_tools/pull/557)
- Settings docs v1.1 [\#556](https://github.com/swift-nav/piksi_tools/pull/556)
- Settings for ntrip and skylark clients. [\#555](https://github.com/swift-nav/piksi_tools/pull/555)
- Client Settings [\#554](https://github.com/swift-nav/piksi_tools/pull/554)

## [v1.1.C](https://github.com/swift-nav/piksi_tools/tree/v1.1.C) (2017-04-26)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.1.B...v1.1.C)

**Closed issues:**

- ImportError: No module named gui\_utils [\#525](https://github.com/swift-nav/piksi_tools/issues/525)

**Merged pull requests:**

- add 230400 choice for baud [\#553](https://github.com/swift-nav/piksi_tools/pull/553)
- add 230400 choice for baud [\#552](https://github.com/swift-nav/piksi_tools/pull/552)
- removed inactive uart info and replaced with network status. [\#551](https://github.com/swift-nav/piksi_tools/pull/551)
- Settings\_view: Update warning when setting could not be set; prevent … [\#550](https://github.com/swift-nav/piksi_tools/pull/550)
- Settings\_view: Update warning when setting could not be set; prevent … [\#549](https://github.com/swift-nav/piksi_tools/pull/549)
- Periodic update release [\#548](https://github.com/swift-nav/piksi_tools/pull/548)
- Periodic update [\#547](https://github.com/swift-nav/piksi_tools/pull/547)
- removed inactive uart info and replaced with network status.  [\#546](https://github.com/swift-nav/piksi_tools/pull/546)
- Fix heading offset descriptor to specify we add the offset value, not… [\#544](https://github.com/swift-nav/piksi_tools/pull/544)

## [v1.1.B](https://github.com/swift-nav/piksi_tools/tree/v1.1.B) (2017-04-14)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.1.A...v1.1.B)

**Closed issues:**

- Old SPP / Float RTK points remain in Piksi Control display [\#524](https://github.com/swift-nav/piksi_tools/issues/524)

**Merged pull requests:**

- Fix heading offset descriptor to specify we subtract the offset value… [\#542](https://github.com/swift-nav/piksi_tools/pull/542)
- Check for IOError during download [\#541](https://github.com/swift-nav/piksi_tools/pull/541)
- Check for IOError during download [\#540](https://github.com/swift-nav/piksi_tools/pull/540)
- Settings v1.1 release [\#539](https://github.com/swift-nav/piksi_tools/pull/539)
- Settings v1.1 [\#538](https://github.com/swift-nav/piksi_tools/pull/538)
- Osx bootstrap [\#536](https://github.com/swift-nav/piksi_tools/pull/536)
- setup.sh: brew swig [\#535](https://github.com/swift-nav/piksi_tools/pull/535)
- Sbp log zipper [\#530](https://github.com/swift-nav/piksi_tools/pull/530)

## [v1.1.A](https://github.com/swift-nav/piksi_tools/tree/v1.1.A) (2017-04-11)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.1.0-branch...v1.1.A)

## [v1.1.0-branch](https://github.com/swift-nav/piksi_tools/tree/v1.1.0-branch) (2017-04-03)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/1.0.A...v1.1.0-branch)

**Closed issues:**

- CSV logs are not created when there is no GPS week from receiver [\#500](https://github.com/swift-nav/piksi_tools/issues/500)
- Make one paragraph UA plan for new 1.1 features [\#488](https://github.com/swift-nav/piksi_tools/issues/488)
- Incorrect flags values in CSV log [\#485](https://github.com/swift-nav/piksi_tools/issues/485)
- Remove Reset IAR and Init with known baseline buttons [\#484](https://github.com/swift-nav/piksi_tools/issues/484)
- Download Latest Firmware saves file in \Program Files folder on Windows [\#483](https://github.com/swift-nav/piksi_tools/issues/483)
- ZeroDivisionError: float division by zero [\#482](https://github.com/swift-nav/piksi_tools/issues/482)

**Merged pull requests:**

- Add heading offset setting to settings.yaml [\#534](https://github.com/swift-nav/piksi_tools/pull/534)
- solution and baseline view: Fix lingering solutions per \#524 [\#533](https://github.com/swift-nav/piksi_tools/pull/533)
- fixup UTC time source, add baseline heading [\#532](https://github.com/swift-nav/piksi_tools/pull/532)
- V2.2.0 sbp [\#531](https://github.com/swift-nav/piksi_tools/pull/531)
- Add Age Corrections and UTC Time msg, rename accuracy fields, reorder… [\#528](https://github.com/swift-nav/piksi_tools/pull/528)
- Initialize accel and gyro arrays which show bogus data on Windows upo… [\#527](https://github.com/swift-nav/piksi_tools/pull/527)
- Adding Klobuchar correction disabler in settings [\#526](https://github.com/swift-nav/piksi_tools/pull/526)
- Cacert finally [\#523](https://github.com/swift-nav/piksi_tools/pull/523)
- Imu view periodic [\#522](https://github.com/swift-nav/piksi_tools/pull/522)
- console.py: fix misunderstood thread.timer, add cmd\_resp callback pri… [\#521](https://github.com/swift-nav/piksi_tools/pull/521)
- Add Gui Utils Module [\#520](https://github.com/swift-nav/piksi_tools/pull/520)
- define basedir for finding image resources [\#519](https://github.com/swift-nav/piksi_tools/pull/519)
- Gui utils [\#518](https://github.com/swift-nav/piksi_tools/pull/518)
- Hdw flow ctrl [\#517](https://github.com/swift-nav/piksi_tools/pull/517)
- Update sbp to 2.1.8 [\#516](https://github.com/swift-nav/piksi_tools/pull/516)
- CSV recording improvements: add local time, reduce duplicated code, d… [\#515](https://github.com/swift-nav/piksi_tools/pull/515)
- console.py Fix certificate paths when outside of Pyinstaller bundle. [\#514](https://github.com/swift-nav/piksi_tools/pull/514)
- Make small usability enhancements to PortChooser and fix cast bug [\#513](https://github.com/swift-nav/piksi_tools/pull/513)
- update\_view: fix undefined local\_stm version with -u [\#512](https://github.com/swift-nav/piksi_tools/pull/512)
- Add linebreak to usage, remove global variables about usage [\#511](https://github.com/swift-nav/piksi_tools/pull/511)
- Add setting for external event sensitivity. [\#510](https://github.com/swift-nav/piksi_tools/pull/510)
- add TCP/IP to console pop-up [\#508](https://github.com/swift-nav/piksi_tools/pull/508)
- Connection icon color [\#507](https://github.com/swift-nav/piksi_tools/pull/507)
- Package Certs in Pyinstaller Binary [\#506](https://github.com/swift-nav/piksi_tools/pull/506)
- Change default firmware download directory to ~/home/SwiftNav [\#505](https://github.com/swift-nav/piksi_tools/pull/505)
- Add PPS settings for polarity, offset and period. [\#504](https://github.com/swift-nav/piksi_tools/pull/504)
- fix import argparse in serial-link.py [\#502](https://github.com/swift-nav/piksi_tools/pull/502)
- Print console version for console log [\#499](https://github.com/swift-nav/piksi_tools/pull/499)
- Fix windows uninstaller so it actually removes the program [\#498](https://github.com/swift-nav/piksi_tools/pull/498)
- Readme popup fix [\#496](https://github.com/swift-nav/piksi_tools/pull/496)
- make sure to close HTTPDriver no matter what when reconnecting [\#495](https://github.com/swift-nav/piksi_tools/pull/495)
- Add erase\_l2c\_capb to settings.yaml [\#494](https://github.com/swift-nav/piksi_tools/pull/494)
- Pop up useage [\#492](https://github.com/swift-nav/piksi_tools/pull/492)
- Add ability to generate readme of the console usage and include in pa… [\#491](https://github.com/swift-nav/piksi_tools/pull/491)
- Removed IAR reset and Init Known Baseline buttons [\#489](https://github.com/swift-nav/piksi_tools/pull/489)
- Fix incompatiblity warning [\#487](https://github.com/swift-nav/piksi_tools/pull/487)
- solution and settings: fix auto survey for no fix message [\#486](https://github.com/swift-nav/piksi_tools/pull/486)
- update\_view: fix version comparison [\#481](https://github.com/swift-nav/piksi_tools/pull/481)
- Skylark catch exceptions [\#467](https://github.com/swift-nav/piksi_tools/pull/467)

## [1.0.A](https://github.com/swift-nav/piksi_tools/tree/1.0.A) (2017-02-09)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.11...1.0.A)

**Merged pull requests:**

- update\_view: fix version comparison [\#480](https://github.com/swift-nav/piksi_tools/pull/480)
- Rename console installers for clarity and brevity [\#478](https://github.com/swift-nav/piksi_tools/pull/478)
- Rename console installers for clarity and brevity [\#477](https://github.com/swift-nav/piksi_tools/pull/477)
- DZ: Respond to settings docs feedback [\#475](https://github.com/swift-nav/piksi_tools/pull/475)

## [v1.0.11](https://github.com/swift-nav/piksi_tools/tree/v1.0.11) (2017-02-09)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30.9...v1.0.11)

**Merged pull requests:**

- settings.yaml: respond to feedback and cleanup [\#476](https://github.com/swift-nav/piksi_tools/pull/476)
- Settings.yaml : doc updated for release. [\#474](https://github.com/swift-nav/piksi_tools/pull/474)
- Change pyparsing version which was broken on OSX [\#473](https://github.com/swift-nav/piksi_tools/pull/473)
- Settings.yaml : doc updated for master. [\#472](https://github.com/swift-nav/piksi_tools/pull/472)
- Update SBP and move to file handles [\#471](https://github.com/swift-nav/piksi_tools/pull/471)
- Change pyparsing version which was broken on OSX [\#470](https://github.com/swift-nav/piksi_tools/pull/470)

## [v0.30.9](https://github.com/swift-nav/piksi_tools/tree/v0.30.9) (2017-02-07)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.10...v0.30.9)

**Merged pull requests:**

- Remove Deprecation Warning [\#469](https://github.com/swift-nav/piksi_tools/pull/469)

## [v1.0.10](https://github.com/swift-nav/piksi_tools/tree/v1.0.10) (2017-02-06)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.9...v1.0.10)

## [v1.0.9](https://github.com/swift-nav/piksi_tools/tree/v1.0.9) (2017-02-06)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.8...v1.0.9)

## [v1.0.8](https://github.com/swift-nav/piksi_tools/tree/v1.0.8) (2017-01-30)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.7...v1.0.8)

## [v1.0.7](https://github.com/swift-nav/piksi_tools/tree/v1.0.7) (2017-01-27)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.6...v1.0.7)

**Closed issues:**

- Put units on tracking tab x axis [\#324](https://github.com/swift-nav/piksi_tools/issues/324)

**Merged pull requests:**

- sbp\_relay\_view: syntax error [\#465](https://github.com/swift-nav/piksi_tools/pull/465)
- sbp\_relay\_view: syntax error [\#464](https://github.com/swift-nav/piksi_tools/pull/464)
- update requirements for sbp 2.1.6 [\#463](https://github.com/swift-nav/piksi_tools/pull/463)
- update requirements for sbp 2.1.6 [\#462](https://github.com/swift-nav/piksi_tools/pull/462)

## [v1.0.6](https://github.com/swift-nav/piksi_tools/tree/v1.0.6) (2017-01-26)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.5...v1.0.6)

**Merged pull requests:**

- Skylark debug master [\#461](https://github.com/swift-nav/piksi_tools/pull/461)
- Improve tar filename and path [\#460](https://github.com/swift-nav/piksi_tools/pull/460)
- Improve tar filename and path [\#459](https://github.com/swift-nav/piksi_tools/pull/459)
- Skylark debug [\#458](https://github.com/swift-nav/piksi_tools/pull/458)
- Update view: initialize update\_dl always [\#457](https://github.com/swift-nav/piksi_tools/pull/457)
- Update view: initialize update\_dl always [\#456](https://github.com/swift-nav/piksi_tools/pull/456)
- Updates for new msg types and PRN counting [\#455](https://github.com/swift-nav/piksi_tools/pull/455)

## [v1.0.5](https://github.com/swift-nav/piksi_tools/tree/v1.0.5) (2017-01-23)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.4...v1.0.5)

**Merged pull requests:**

- Settings View: fix bug in selected setting [\#454](https://github.com/swift-nav/piksi_tools/pull/454)
- Settings View: fix bug in selected setting [\#453](https://github.com/swift-nav/piksi_tools/pull/453)
- settings: add first cut at docstrings [\#450](https://github.com/swift-nav/piksi_tools/pull/450)
- settings: add first cut at docstrings [\#449](https://github.com/swift-nav/piksi_tools/pull/449)

## [v1.0.4](https://github.com/swift-nav/piksi_tools/tree/v1.0.4) (2017-01-20)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.3...v1.0.4)

**Merged pull requests:**

- Tracking\_view: limit xrange to 100 seconds [\#452](https://github.com/swift-nav/piksi_tools/pull/452)
- Tracking\_view: limit xrange to 100 seconds [\#451](https://github.com/swift-nav/piksi_tools/pull/451)
- USB upgrade UI improvements \(release\) [\#448](https://github.com/swift-nav/piksi_tools/pull/448)
- USB upgrade UI improvements \(master\) [\#447](https://github.com/swift-nav/piksi_tools/pull/447)
- fix bug in settings view when nothing selected [\#446](https://github.com/swift-nav/piksi_tools/pull/446)
- fix bug in settings view when nothing selected [\#445](https://github.com/swift-nav/piksi_tools/pull/445)

## [v1.0.3](https://github.com/swift-nav/piksi_tools/tree/v1.0.3) (2017-01-19)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.2...v1.0.3)

## [v1.0.2](https://github.com/swift-nav/piksi_tools/tree/v1.0.2) (2017-01-17)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.1...v1.0.2)

**Closed issues:**

- Final version of Piksi v2 console and warning pop-ups [\#393](https://github.com/swift-nav/piksi_tools/issues/393)
- Release v0.30 console [\#340](https://github.com/swift-nav/piksi_tools/issues/340)
- Respond to failed tests on Console for v0.30 release [\#339](https://github.com/swift-nav/piksi_tools/issues/339)
- Test v0.30 console [\#338](https://github.com/swift-nav/piksi_tools/issues/338)
- Software update pop-up displays incorrect link [\#335](https://github.com/swift-nav/piksi_tools/issues/335)
- Limit the time on the baseline and solution tab to 3 decimal digits. [\#325](https://github.com/swift-nav/piksi_tools/issues/325)
- Add try catch statement in so that the console still works without write permissions for the csv files [\#295](https://github.com/swift-nav/piksi_tools/issues/295)
- fix up rinex recording in console for observation type 0x49 [\#293](https://github.com/swift-nav/piksi_tools/issues/293)
- Fix time resolution in CSV files [\#282](https://github.com/swift-nav/piksi_tools/issues/282)
- console from .dmg asks to install GIT [\#245](https://github.com/swift-nav/piksi_tools/issues/245)

**Merged pull requests:**

- Fix default UUID [\#444](https://github.com/swift-nav/piksi_tools/pull/444)
- update\_view: Catch URLError [\#443](https://github.com/swift-nav/piksi_tools/pull/443)
- update\_view: Catch URLError [\#442](https://github.com/swift-nav/piksi_tools/pull/442)
- Fix default UUID [\#440](https://github.com/swift-nav/piksi_tools/pull/440)
- Allow calling settings read callbacks multiple times \(release PR\) [\#439](https://github.com/swift-nav/piksi_tools/pull/439)
- Allow calling settings read callbacks multiple times \(master PR\) [\#438](https://github.com/swift-nav/piksi_tools/pull/438)
- Update view suppress warning \(release branch PR\) [\#437](https://github.com/swift-nav/piksi_tools/pull/437)
- Update view fixes release [\#436](https://github.com/swift-nav/piksi_tools/pull/436)

## [v1.0.1](https://github.com/swift-nav/piksi_tools/tree/v1.0.1) (2017-01-13)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.0...v1.0.1)

**Merged pull requests:**

- update\_view: don't use nap for nagware check either [\#435](https://github.com/swift-nav/piksi_tools/pull/435)
- update\_view: don't look for nap version keys [\#431](https://github.com/swift-nav/piksi_tools/pull/431)

## [v1.0.0](https://github.com/swift-nav/piksi_tools/tree/v1.0.0) (2017-01-12)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v1.0.0-branch...v1.0.0)

## [v1.0.0-branch](https://github.com/swift-nav/piksi_tools/tree/v1.0.0-branch) (2017-01-11)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.32-rc2...v1.0.0-branch)

## [v0.32-rc2](https://github.com/swift-nav/piksi_tools/tree/v0.32-rc2) (2017-01-11)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30.8...v0.32-rc2)

**Merged pull requests:**

- Update firmware upgrade text [\#430](https://github.com/swift-nav/piksi_tools/pull/430)
- Add a pip list to .travis.yaml for documentation, install after build [\#429](https://github.com/swift-nav/piksi_tools/pull/429)
- Fix no list baudrate and port [\#428](https://github.com/swift-nav/piksi_tools/pull/428)
- setup.sh: Robustly install python [\#427](https://github.com/swift-nav/piksi_tools/pull/427)
- Skylark uuid [\#426](https://github.com/swift-nav/piksi_tools/pull/426)
- Different versions of PyInstaller for linux and osx [\#425](https://github.com/swift-nav/piksi_tools/pull/425)
- Swift console rename [\#424](https://github.com/swift-nav/piksi_tools/pull/424)

## [v0.30.8](https://github.com/swift-nav/piksi_tools/tree/v0.30.8) (2017-01-09)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.32-rc1...v0.30.8)

## [v0.32-rc1](https://github.com/swift-nav/piksi_tools/tree/v0.32-rc1) (2017-01-07)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.31.3...v0.32-rc1)

**Closed issues:**

- Add command line arguments for rover,base and connections to skylark [\#394](https://github.com/swift-nav/piksi_tools/issues/394)

**Merged pull requests:**

- v0.33 fixes [\#423](https://github.com/swift-nav/piksi_tools/pull/423)
- Skylark cmdline [\#422](https://github.com/swift-nav/piksi_tools/pull/422)
- Add tar make target [\#421](https://github.com/swift-nav/piksi_tools/pull/421)
- Osx qt 4.8.5 [\#420](https://github.com/swift-nav/piksi_tools/pull/420)
- Udev rules [\#419](https://github.com/swift-nav/piksi_tools/pull/419)
- WIP: serial\_link.py: Use CDC driver [\#415](https://github.com/swift-nav/piksi_tools/pull/415)
- update\_view improvements and hiding of feature [\#413](https://github.com/swift-nav/piksi_tools/pull/413)
- V0.33 fix 5 [\#404](https://github.com/swift-nav/piksi_tools/pull/404)

## [v0.31.3](https://github.com/swift-nav/piksi_tools/tree/v0.31.3) (2017-01-04)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30.7...v0.31.3)

## [v0.30.7](https://github.com/swift-nav/piksi_tools/tree/v0.30.7) (2017-01-03)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30.5...v0.30.7)

**Closed issues:**

- Unexpected tracking channel legend behavior in console [\#403](https://github.com/swift-nav/piksi_tools/issues/403)
- commandl line upgrade unhandled failure case [\#391](https://github.com/swift-nav/piksi_tools/issues/391)

**Merged pull requests:**

- console.py: fix misunderstood thread.timer, add cmd\_resp callback pri… [\#417](https://github.com/swift-nav/piksi_tools/pull/417)
- Fix uuid test for negative serial numbers [\#416](https://github.com/swift-nav/piksi_tools/pull/416)
- rename console event log [\#414](https://github.com/swift-nav/piksi_tools/pull/414)
- only put legend entries for currently tracked items [\#412](https://github.com/swift-nav/piksi_tools/pull/412)
- tracking\_view: fix dict iteration that wasn't thread safe [\#411](https://github.com/swift-nav/piksi_tools/pull/411)
- Update install docs [\#409](https://github.com/swift-nav/piksi_tools/pull/409)
- Elevation mask settings [\#408](https://github.com/swift-nav/piksi_tools/pull/408)
- Cdc osx fix [\#407](https://github.com/swift-nav/piksi_tools/pull/407)
- Fixes for firmware update on Windows [\#406](https://github.com/swift-nav/piksi_tools/pull/406)
- fix serial-link negative serial number problem [\#405](https://github.com/swift-nav/piksi_tools/pull/405)
- V0.33 fix 3 [\#402](https://github.com/swift-nav/piksi_tools/pull/402)
- Piksi console -\> Swift console rename [\#401](https://github.com/swift-nav/piksi_tools/pull/401)
- initialize response dict [\#392](https://github.com/swift-nav/piksi_tools/pull/392)

## [v0.30.5](https://github.com/swift-nav/piksi_tools/tree/v0.30.5) (2016-12-16)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30.3...v0.30.5)

**Merged pull requests:**

- Use the new MsgReset from libsbp. [\#400](https://github.com/swift-nav/piksi_tools/pull/400)
- bug\_fixes [\#399](https://github.com/swift-nav/piksi_tools/pull/399)

## [v0.30.3](https://github.com/swift-nav/piksi_tools/tree/v0.30.3) (2016-12-15)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30.4...v0.30.3)

**Merged pull requests:**

- Add hardware incompatibility warning for Piksi v2 [\#398](https://github.com/swift-nav/piksi_tools/pull/398)

## [v0.30.4](https://github.com/swift-nav/piksi_tools/tree/v0.30.4) (2016-12-15)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30.2...v0.30.4)

## [v0.30.2](https://github.com/swift-nav/piksi_tools/tree/v0.30.2) (2016-12-15)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30.1...v0.30.2)

## [v0.30.1](https://github.com/swift-nav/piksi_tools/tree/v0.30.1) (2016-12-15)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.31.2...v0.30.1)

**Closed issues:**

- Observation tab showing old observations [\#383](https://github.com/swift-nav/piksi_tools/issues/383)
- Fix tracking view for SBP 2.x [\#379](https://github.com/swift-nav/piksi_tools/issues/379)

**Merged pull requests:**

- V0.33 improvements [\#397](https://github.com/swift-nav/piksi_tools/pull/397)
- Update to latest libsbp \(for raw IMU support\) [\#396](https://github.com/swift-nav/piksi_tools/pull/396)
- Fix directory typo in .travis.yaml [\#390](https://github.com/swift-nav/piksi_tools/pull/390)
- Console based firmware update for Piksi Multi [\#389](https://github.com/swift-nav/piksi_tools/pull/389)
- add linux packaging to makefile [\#388](https://github.com/swift-nav/piksi_tools/pull/388)
- Add\_os postfix for console ci build results [\#387](https://github.com/swift-nav/piksi_tools/pull/387)
- Remove old observations from the table [\#386](https://github.com/swift-nav/piksi_tools/pull/386)
- IMU raw data support [\#385](https://github.com/swift-nav/piksi_tools/pull/385)
- fix tracking\_view in simulation mode and future proof [\#382](https://github.com/swift-nav/piksi_tools/pull/382)
- remove old solution's latest cross point [\#381](https://github.com/swift-nav/piksi_tools/pull/381)
- tracking.py: add filters for L1 vs L2 tracking [\#378](https://github.com/swift-nav/piksi_tools/pull/378)

## [v0.31.2](https://github.com/swift-nav/piksi_tools/tree/v0.31.2) (2016-12-08)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.31.1...v0.31.2)

**Closed issues:**

- implement sbp 2.0 changes [\#362](https://github.com/swift-nav/piksi_tools/issues/362)
- new bootload script for V3 [\#357](https://github.com/swift-nav/piksi_tools/issues/357)
- Solution tab should integrate SPP and RTK solutions [\#354](https://github.com/swift-nav/piksi_tools/issues/354)
- L2P observation do not show correctly [\#353](https://github.com/swift-nav/piksi_tools/issues/353)
- Observation view fixes:  [\#327](https://github.com/swift-nav/piksi_tools/issues/327)
- Have the Position center button be applied after the zoom all button.  [\#326](https://github.com/swift-nav/piksi_tools/issues/326)

**Merged pull requests:**

- Add MSG\_OBS to skylark whitelist [\#380](https://github.com/swift-nav/piksi_tools/pull/380)
- console.py tweeks: cmd line arg for console log, use EMPTY\_STR macro … [\#377](https://github.com/swift-nav/piksi_tools/pull/377)
- Improve ObservationView handling of SBP 2.x [\#376](https://github.com/swift-nav/piksi_tools/pull/376)
- Bootload Piksi v3 [\#370](https://github.com/swift-nav/piksi_tools/pull/370)

## [v0.31.1](https://github.com/swift-nav/piksi_tools/tree/v0.31.1) (2016-12-01)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.31...v0.31.1)

**Merged pull requests:**

- fix toolbar num\_sats [\#375](https://github.com/swift-nav/piksi_tools/pull/375)

## [v0.31](https://github.com/swift-nav/piksi_tools/tree/v0.31) (2016-12-01)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30-rc2...v0.31)

**Closed issues:**

- Toggle something on the display with each heartbeat  [\#342](https://github.com/swift-nav/piksi_tools/issues/342)

**Merged pull requests:**

- remove debug [\#374](https://github.com/swift-nav/piksi_tools/pull/374)
- Obs v2.0 [\#373](https://github.com/swift-nav/piksi_tools/pull/373)
- Sbp 2.0 vel dops time [\#372](https://github.com/swift-nav/piksi_tools/pull/372)
- Sbp 2.0 new msg [\#371](https://github.com/swift-nav/piksi_tools/pull/371)
- Text fmt [\#369](https://github.com/swift-nav/piksi_tools/pull/369)
- Sbp2.0 [\#366](https://github.com/swift-nav/piksi_tools/pull/366)
- Pick up new SBP 2.0 [\#365](https://github.com/swift-nav/piksi_tools/pull/365)
- remove osx versions that seem to fail on Travis [\#364](https://github.com/swift-nav/piksi_tools/pull/364)
- Make settings erase work for V2 and V3. [\#363](https://github.com/swift-nav/piksi_tools/pull/363)
- Change from 'SATS' to 'Signals' [\#361](https://github.com/swift-nav/piksi_tools/pull/361)
- increase travis\_wait [\#360](https://github.com/swift-nav/piksi_tools/pull/360)

## [v0.30-rc2](https://github.com/swift-nav/piksi_tools/tree/v0.30-rc2) (2016-11-02)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.30-rc1...v0.30-rc2)

**Merged pull requests:**

- V30 rc2 [\#359](https://github.com/swift-nav/piksi_tools/pull/359)
- Cnx icon blink [\#347](https://github.com/swift-nav/piksi_tools/pull/347)

## [v0.30-rc1](https://github.com/swift-nav/piksi_tools/tree/v0.30-rc1) (2016-11-01)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.29...v0.30-rc1)

**Closed issues:**

- Set default baudrate to 115200 in console and else where in the tools [\#352](https://github.com/swift-nav/piksi_tools/issues/352)
- Verify that UART status message display works with V0.21 and piksi\_firmware\_master [\#328](https://github.com/swift-nav/piksi_tools/issues/328)
- change labels on observation view from rover and base to local and remote [\#294](https://github.com/swift-nav/piksi_tools/issues/294)
- running from dmg [\#258](https://github.com/swift-nav/piksi_tools/issues/258)
- Button to start SBP log recording from the console [\#63](https://github.com/swift-nav/piksi_tools/issues/63)

**Merged pull requests:**

- If networking connection breaks, attempt reconnection. [\#358](https://github.com/swift-nav/piksi_tools/pull/358)
- Configurable device id's [\#356](https://github.com/swift-nav/piksi_tools/pull/356)
- Handle L1P and L2P. Fix bugs in calculating GPS PRN numbers. [\#355](https://github.com/swift-nav/piksi_tools/pull/355)
- Configurable base and rover device [\#351](https://github.com/swift-nav/piksi_tools/pull/351)
- add gui baudrate toggle [\#346](https://github.com/swift-nav/piksi_tools/pull/346)
- New SBP [\#337](https://github.com/swift-nav/piksi_tools/pull/337)
- Update console.py [\#334](https://github.com/swift-nav/piksi_tools/pull/334)
- Sbp2rinex [\#292](https://github.com/swift-nav/piksi_tools/pull/292)
- Creates interpolate\_event\_positions.py  [\#187](https://github.com/swift-nav/piksi_tools/pull/187)

## [v0.29](https://github.com/swift-nav/piksi_tools/tree/v0.29) (2016-08-10)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.28...v0.29)

**Merged pull requests:**

- Update solution\_view.py [\#333](https://github.com/swift-nav/piksi_tools/pull/333)
- V0.28 showstopper fixes [\#330](https://github.com/swift-nav/piksi_tools/pull/330)
- Windows fixes [\#317](https://github.com/swift-nav/piksi_tools/pull/317)

## [v0.28](https://github.com/swift-nav/piksi_tools/tree/v0.28) (2016-08-03)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.28-rc2...v0.28)

## [v0.28-rc2](https://github.com/swift-nav/piksi_tools/tree/v0.28-rc2) (2016-08-03)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.27...v0.28-rc2)

**Closed issues:**

- make the CSV logging respect the -o arguement if it is a directory [\#291](https://github.com/swift-nav/piksi_tools/issues/291)
- Remove -e option [\#285](https://github.com/swift-nav/piksi_tools/issues/285)
- Add status bar [\#278](https://github.com/swift-nav/piksi_tools/issues/278)
- make sure CSV files end up in the location from -o command [\#261](https://github.com/swift-nav/piksi_tools/issues/261)
- Add button to enable/disable CSV logging [\#150](https://github.com/swift-nav/piksi_tools/issues/150)
- Put an annotation in the "RTK Position" tab of the console indicating what settings are required for the tab to display information. [\#62](https://github.com/swift-nav/piksi_tools/issues/62)
- Console does not work well with no write permissions in "program files" on Windows [\#51](https://github.com/swift-nav/piksi_tools/issues/51)
- Move console into its own repo? [\#19](https://github.com/swift-nav/piksi_tools/issues/19)
- Add mean of dumping Piksi settings to machine readable format. [\#11](https://github.com/swift-nav/piksi_tools/issues/11)

**Merged pull requests:**

- fixed that weird flip flop of slashes in windows [\#316](https://github.com/swift-nav/piksi_tools/pull/316)
- fixed directory bug for windows [\#315](https://github.com/swift-nav/piksi_tools/pull/315)
- don't expect "which" to exist on windows [\#313](https://github.com/swift-nav/piksi_tools/pull/313)
- Update solution\_view.py [\#311](https://github.com/swift-nav/piksi_tools/pull/311)
- changed Rover to Local and Base to Remote [\#310](https://github.com/swift-nav/piksi_tools/pull/310)
- Tracking View: Move, Resize, & toggle legend [\#304](https://github.com/swift-nav/piksi_tools/pull/304)
- Auto survey 2 [\#303](https://github.com/swift-nav/piksi_tools/pull/303)
- Add console status bar; simplify logging infrastructure. [\#301](https://github.com/swift-nav/piksi_tools/pull/301)
- Update console.py [\#300](https://github.com/swift-nav/piksi_tools/pull/300)
- Staging + Virtual Observations [\#296](https://github.com/swift-nav/piksi_tools/pull/296)
- console.py: remove -e cmd line arg [\#290](https://github.com/swift-nav/piksi_tools/pull/290)

## [v0.27](https://github.com/swift-nav/piksi_tools/tree/v0.27) (2016-06-03)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.27-rc1...v0.27)

**Merged pull requests:**

- Make sure new console works with v0.21 firmware WRT skylark and sbp\_r… [\#288](https://github.com/swift-nav/piksi_tools/pull/288)

## [v0.27-rc1](https://github.com/swift-nav/piksi_tools/tree/v0.27-rc1) (2016-06-01)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.26...v0.27-rc1)

**Fixed bugs:**

- Error message for bad device permissions is contradictory [\#241](https://github.com/swift-nav/piksi_tools/issues/241)

**Closed issues:**

- update piksi\_tools for latest version of SBP [\#250](https://github.com/swift-nav/piksi_tools/issues/250)
- Survey Position Auto Populate [\#180](https://github.com/swift-nav/piksi_tools/issues/180)
- typo in help notes for settings: [\#173](https://github.com/swift-nav/piksi_tools/issues/173)
- Console: in Solution tab, instruct user to turn on Basestation mode for RTK subtab [\#135](https://github.com/swift-nav/piksi_tools/issues/135)
- Console - Change the value of "IAR Num. Hyps." when pending IAR [\#121](https://github.com/swift-nav/piksi_tools/issues/121)
- Allow users to choose location of saved logfiles in the console  [\#33](https://github.com/swift-nav/piksi_tools/issues/33)

**Merged pull requests:**

- Nsis improvements [\#287](https://github.com/swift-nav/piksi_tools/pull/287)
- Rebase axlan windows [\#286](https://github.com/swift-nav/piksi_tools/pull/286)
- New obs 2 [\#283](https://github.com/swift-nav/piksi_tools/pull/283)
- Add support for L2CM observations [\#276](https://github.com/swift-nav/piksi_tools/pull/276)
- Output code of the signal in tracking view legend [\#271](https://github.com/swift-nav/piksi_tools/pull/271)
- Updated annotations in settings.yaml [\#270](https://github.com/swift-nav/piksi_tools/pull/270)
- CNo theshold [\#266](https://github.com/swift-nav/piksi_tools/pull/266)
- Ci exit on error option [\#264](https://github.com/swift-nav/piksi_tools/pull/264)
- Added generic AT Commands to console [\#263](https://github.com/swift-nav/piksi_tools/pull/263)
- Expert toggle [\#262](https://github.com/swift-nav/piksi_tools/pull/262)
- Add option to use TCP host/port. [\#260](https://github.com/swift-nav/piksi_tools/pull/260)
- observation\_view: show carrier frequency \(time diff of carrier phase\) [\#259](https://github.com/swift-nav/piksi_tools/pull/259)
- check and make sure git actually exists before trying to use it [\#256](https://github.com/swift-nav/piksi_tools/pull/256)
- Update branding [\#255](https://github.com/swift-nav/piksi_tools/pull/255)
- Requirements work [\#254](https://github.com/swift-nav/piksi_tools/pull/254)
- Update sbp [\#253](https://github.com/swift-nav/piksi_tools/pull/253)
- Add settings.py to read and write Piksi settings from the terminal [\#246](https://github.com/swift-nav/piksi_tools/pull/246)
- Sasha clarify console text [\#244](https://github.com/swift-nav/piksi_tools/pull/244)
- move import of piksi\_tools.console.utils until after the toolkit was set [\#243](https://github.com/swift-nav/piksi_tools/pull/243)
- Uart period [\#239](https://github.com/swift-nav/piksi_tools/pull/239)
- Sbp wrapper [\#236](https://github.com/swift-nav/piksi_tools/pull/236)
- fix UARTB message mask default value \(typo in settings.yaml\) [\#235](https://github.com/swift-nav/piksi_tools/pull/235)
- Rtk position tab annotated [\#234](https://github.com/swift-nav/piksi_tools/pull/234)
- add 'v' character to all displays of local console version [\#233](https://github.com/swift-nav/piksi_tools/pull/233)
- only display IAR hypothesis count if it is current and not 1.  [\#232](https://github.com/swift-nav/piksi_tools/pull/232)
- Correctly adjust PRNs for SBAS. [\#230](https://github.com/swift-nav/piksi_tools/pull/230)
- add notes regarding the NMEA message rates [\#229](https://github.com/swift-nav/piksi_tools/pull/229)
- Replace reset. [\#228](https://github.com/swift-nav/piksi_tools/pull/228)
- remove nargs=1, fix append-log-filename [\#227](https://github.com/swift-nav/piksi_tools/pull/227)
- add optional timeout to Diagnostics initializer [\#221](https://github.com/swift-nav/piksi_tools/pull/221)
- update simulator generator script for almanac struct changes [\#212](https://github.com/swift-nav/piksi_tools/pull/212)
- Add settings for OpenLog [\#194](https://github.com/swift-nav/piksi_tools/pull/194)
- added a command line argument to bootload for max queued ops [\#186](https://github.com/swift-nav/piksi_tools/pull/186)

## [v0.26](https://github.com/swift-nav/piksi_tools/tree/v0.26) (2015-12-07)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.25...v0.26)

**Fixed bugs:**

- Constrain console python dependencies. [\#218](https://github.com/swift-nav/piksi_tools/pull/218)

**Closed issues:**

- Resolve libsbp serial client freezing in the console [\#204](https://github.com/swift-nav/piksi_tools/issues/204)
- Coordinate an onboarding test for HTTP use with console [\#203](https://github.com/swift-nav/piksi_tools/issues/203)
- Test console for OS X, Windows release [\#202](https://github.com/swift-nav/piksi_tools/issues/202)
- Add HTTP connection tab on the console [\#201](https://github.com/swift-nav/piksi_tools/issues/201)
- Reformat update firmware screen, fixup ability to flash STM and NAP separately [\#105](https://github.com/swift-nav/piksi_tools/issues/105)

**Merged pull requests:**

- Better help for HTTP gets. [\#225](https://github.com/swift-nav/piksi_tools/pull/225)
- Update console build instructions. [\#224](https://github.com/swift-nav/piksi_tools/pull/224)
- Use git tag describe for console command line version. [\#223](https://github.com/swift-nav/piksi_tools/pull/223)
- Console updates for HTTP POST. [\#222](https://github.com/swift-nav/piksi_tools/pull/222)

## [v0.25](https://github.com/swift-nav/piksi_tools/tree/v0.25) (2015-11-24)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.25-rc0...v0.25)

**Fixed bugs:**

- Packaging fixes for console and HOWTO documentation. [\#214](https://github.com/swift-nav/piksi_tools/pull/214)

**Merged pull requests:**

- Icons [\#217](https://github.com/swift-nav/piksi_tools/pull/217)
- Requirements adjustments for windows build [\#215](https://github.com/swift-nav/piksi_tools/pull/215)

## [v0.25-rc0](https://github.com/swift-nav/piksi_tools/tree/v0.25-rc0) (2015-11-20)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.24.3...v0.25-rc0)

**Fixed bugs:**

- All-NaN slice encountered, stack blown [\#160](https://github.com/swift-nav/piksi_tools/issues/160)
- Fix `tox` test for clean install [\#191](https://github.com/swift-nav/piksi_tools/pull/191)
- Hotfix handler interface. [\#157](https://github.com/swift-nav/piksi_tools/pull/157)

**Closed issues:**

- A Few Missing Dependencies. [\#209](https://github.com/swift-nav/piksi_tools/issues/209)
- Update HTTP base station argument for serial link and console. [\#152](https://github.com/swift-nav/piksi_tools/issues/152)
- Tracking CN0 axis should start at 30 [\#110](https://github.com/swift-nav/piksi_tools/issues/110)

**Merged pull requests:**

- Console updates for v0.21 firmware [\#211](https://github.com/swift-nav/piksi_tools/pull/211)
- add udp\_receive prototype [\#208](https://github.com/swift-nav/piksi_tools/pull/208)
- prn vs sid vs sid.sat vs .... ? [\#207](https://github.com/swift-nav/piksi_tools/pull/207)
- Change default UartA Baud text in settings [\#206](https://github.com/swift-nav/piksi_tools/pull/206)
- make sure return code is 1 when bootload fails due to timeout [\#197](https://github.com/swift-nav/piksi_tools/pull/197)
- implement timeout on bootload [\#196](https://github.com/swift-nav/piksi_tools/pull/196)
- Modify get\_driver to exit with return code upon failure. [\#195](https://github.com/swift-nav/piksi_tools/pull/195)
- Add Console settings entry for configurable PPS width. [\#193](https://github.com/swift-nav/piksi_tools/pull/193)
- Replace Ansible with simpler bash script. [\#192](https://github.com/swift-nav/piksi_tools/pull/192)
- updates to build scripts; move more things into requirements.txt [\#190](https://github.com/swift-nav/piksi_tools/pull/190)
- Revert "updates to build scripts; move more things into requirements.… [\#189](https://github.com/swift-nav/piksi_tools/pull/189)
- updates to build scripts; move more things into requirements.txt [\#188](https://github.com/swift-nav/piksi_tools/pull/188)
- allow user to specify a directory with -o arg [\#184](https://github.com/swift-nav/piksi_tools/pull/184)
- Networking updates. [\#183](https://github.com/swift-nav/piksi_tools/pull/183)
- add print to diagnostics to warn HITL users of a hard fault or NAP/ST… [\#177](https://github.com/swift-nav/piksi_tools/pull/177)
- Piksi tools integration for a networking client. [\#176](https://github.com/swift-nav/piksi_tools/pull/176)
- Fix display of thread cpu usage. [\#175](https://github.com/swift-nav/piksi_tools/pull/175)
- fix print bug on console for legacy messages [\#174](https://github.com/swift-nav/piksi_tools/pull/174)
- Update requirements: specific intelhex version, add numpy [\#171](https://github.com/swift-nav/piksi_tools/pull/171)
- Revert "Use new PRN field from signal." [\#170](https://github.com/swift-nav/piksi_tools/pull/170)
- Console list tweaks [\#169](https://github.com/swift-nav/piksi_tools/pull/169)
- Mavlink analysis [\#168](https://github.com/swift-nav/piksi_tools/pull/168)
- Output list fixes [\#166](https://github.com/swift-nav/piksi_tools/pull/166)
- SERIAL\_LINK: Print log message levels and newlines [\#165](https://github.com/swift-nav/piksi_tools/pull/165)
- Bootloader tests [\#163](https://github.com/swift-nav/piksi_tools/pull/163)
- Remove software-based watchdog [\#162](https://github.com/swift-nav/piksi_tools/pull/162)
- Use new PRN field from signal. [\#161](https://github.com/swift-nav/piksi_tools/pull/161)
- Use libsbp message classes instead of struct.unpack. [\#158](https://github.com/swift-nav/piksi_tools/pull/158)
- Independent update, update view ui improvements [\#156](https://github.com/swift-nav/piksi_tools/pull/156)
- Output list [\#155](https://github.com/swift-nav/piksi_tools/pull/155)
- Tracking view rescale [\#154](https://github.com/swift-nav/piksi_tools/pull/154)
- Update libsbp interfaces. [\#151](https://github.com/swift-nav/piksi_tools/pull/151)
- Mavlink decode and Ardupilot subdirectory [\#149](https://github.com/swift-nav/piksi_tools/pull/149)
- Add context support to STMUniqueID for bringup script. [\#147](https://github.com/swift-nav/piksi_tools/pull/147)
- console: Square axes when zoom all selected. [\#142](https://github.com/swift-nav/piksi_tools/pull/142)

## [v0.24.3](https://github.com/swift-nav/piksi_tools/tree/v0.24.3) (2015-08-06)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.24.2...v0.24.3)

**Merged pull requests:**

- Nullify pip installation garbage. [\#148](https://github.com/swift-nav/piksi_tools/pull/148)
- Updates to USRP script. [\#146](https://github.com/swift-nav/piksi_tools/pull/146)
- Handle backwards ACQ results. [\#145](https://github.com/swift-nav/piksi_tools/pull/145)
- Play scenario from SSD instead of HD. [\#141](https://github.com/swift-nav/piksi_tools/pull/141)
- Add units to settings info. [\#139](https://github.com/swift-nav/piksi_tools/pull/139)

## [v0.24.2](https://github.com/swift-nav/piksi_tools/tree/v0.24.2) (2015-07-24)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.24.1...v0.24.2)

**Closed issues:**

- Baseline plotting bug [\#131](https://github.com/swift-nav/piksi_tools/issues/131)

**Merged pull requests:**

- V0.24 branch merge back into master [\#140](https://github.com/swift-nav/piksi_tools/pull/140)
- baseline: Fix barfing on NaNs when there's no data. [\#138](https://github.com/swift-nav/piksi_tools/pull/138)
- Pull out playback parameter. [\#137](https://github.com/swift-nav/piksi_tools/pull/137)

## [v0.24.1](https://github.com/swift-nav/piksi_tools/tree/v0.24.1) (2015-07-24)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.24...v0.24.1)

**Merged pull requests:**

- Runner for USRP HITL test. [\#132](https://github.com/swift-nav/piksi_tools/pull/132)

## [v0.24](https://github.com/swift-nav/piksi_tools/tree/v0.24) (2015-07-22)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.24-rc2...v0.24)

**Merged pull requests:**

- fix acq, one of the console issues [\#134](https://github.com/swift-nav/piksi_tools/pull/134)

## [v0.24-rc2](https://github.com/swift-nav/piksi_tools/tree/v0.24-rc2) (2015-07-22)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.14-rc2...v0.24-rc2)

## [v0.14-rc2](https://github.com/swift-nav/piksi_tools/tree/v0.14-rc2) (2015-07-22)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.24-rc1...v0.14-rc2)

**Implemented enhancements:**

- USRP testing script [\#133](https://github.com/swift-nav/piksi_tools/issues/133)
- Console: plot fixed baseline solutions in different color than float [\#101](https://github.com/swift-nav/piksi_tools/issues/101)

**Merged pull requests:**

- fix window sizing issues introduced by reset button [\#130](https://github.com/swift-nav/piksi_tools/pull/130)
- New log messages [\#129](https://github.com/swift-nav/piksi_tools/pull/129)
- Move to deprecated msg print [\#128](https://github.com/swift-nav/piksi_tools/pull/128)
- SETTINGS: Add/change various tracking / solution settings defs [\#126](https://github.com/swift-nav/piksi_tools/pull/126)
- Fix satellite masking backwards compatibility [\#123](https://github.com/swift-nav/piksi_tools/pull/123)
- add backwards compatibility for MSGTrackStateDepA and update for new … [\#120](https://github.com/swift-nav/piksi_tools/pull/120)
- testing: ChibiOS thread support in core dumps. [\#115](https://github.com/swift-nav/piksi_tools/pull/115)
- fileio: Use libsbp message defs. [\#114](https://github.com/swift-nav/piksi_tools/pull/114)
- CONSOLE: visually distinguish fixed from float baselines [\#106](https://github.com/swift-nav/piksi_tools/pull/106)

## [v0.24-rc1](https://github.com/swift-nav/piksi_tools/tree/v0.24-rc1) (2015-07-13)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.24-rc0...v0.24-rc1)

**Merged pull requests:**

- Missed tracking view handling [\#118](https://github.com/swift-nav/piksi_tools/pull/118)
- Deprecated -\> DepA [\#116](https://github.com/swift-nav/piksi_tools/pull/116)
- Bootloader integration tests \(rebased\) [\#113](https://github.com/swift-nav/piksi_tools/pull/113)

## [v0.24-rc0](https://github.com/swift-nav/piksi_tools/tree/v0.24-rc0) (2015-07-10)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.23...v0.24-rc0)

**Closed issues:**

- Bootload client should repeatedly try to reset the Piksi [\#39](https://github.com/swift-nav/piksi_tools/issues/39)
- After flashing firmware, need to update Version strings [\#27](https://github.com/swift-nav/piksi_tools/issues/27)
- Remove init known baseline feature from console [\#24](https://github.com/swift-nav/piksi_tools/issues/24)

**Merged pull requests:**

- Support for widened PRN [\#112](https://github.com/swift-nav/piksi_tools/pull/112)
- update expert settings for new settings messages [\#108](https://github.com/swift-nav/piksi_tools/pull/108)
- fix line breaks on CSV headers [\#107](https://github.com/swift-nav/piksi_tools/pull/107)
- CONSOLE: hide expert settings by default [\#104](https://github.com/swift-nav/piksi_tools/pull/104)
- CONSOLE: Terminate on Ctrl-C from cmd line [\#103](https://github.com/swift-nav/piksi_tools/pull/103)
- NMEA settings information for the console. [\#102](https://github.com/swift-nav/piksi_tools/pull/102)
- add action logger \(clone of serial link with possibility of talking to device\) [\#97](https://github.com/swift-nav/piksi_tools/pull/97)
- Update dependency installation instructions in the README [\#92](https://github.com/swift-nav/piksi_tools/pull/92)
- update makefile to name windows setup.exe [\#91](https://github.com/swift-nav/piksi_tools/pull/91)
- testing: Hack core dumper to work with Python 3. [\#89](https://github.com/swift-nav/piksi_tools/pull/89)
- Update to new file\_io messages [\#84](https://github.com/swift-nav/piksi_tools/pull/84)
- New settings [\#82](https://github.com/swift-nav/piksi_tools/pull/82)

## [v0.23](https://github.com/swift-nav/piksi_tools/tree/v0.23) (2015-06-26)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.23-rc1...v0.23)

**Merged pull requests:**

- add iq\_output\_mask to settings.yaml to avoid warning [\#90](https://github.com/swift-nav/piksi_tools/pull/90)
- A Docker container for piksi\_tools [\#77](https://github.com/swift-nav/piksi_tools/pull/77)

## [v0.23-rc1](https://github.com/swift-nav/piksi_tools/tree/v0.23-rc1) (2015-06-25)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.23-rc0...v0.23-rc1)

**Merged pull requests:**

- Improve bootloader, update log output [\#88](https://github.com/swift-nav/piksi_tools/pull/88)

## [v0.23-rc0](https://github.com/swift-nav/piksi_tools/tree/v0.23-rc0) (2015-06-25)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.22...v0.23-rc0)

**Closed issues:**

- Running piksi\_tools from source options are confusing [\#75](https://github.com/swift-nav/piksi_tools/issues/75)

**Merged pull requests:**

- More robust diagnostics [\#87](https://github.com/swift-nav/piksi_tools/pull/87)
- Script to check firmware/nap settings on test. [\#85](https://github.com/swift-nav/piksi_tools/pull/85)
- Update SBP, message renaming [\#81](https://github.com/swift-nav/piksi_tools/pull/81)
- serial\_link: exit when serial receive thread exits. [\#80](https://github.com/swift-nav/piksi_tools/pull/80)
- Use gdb-multiarch for core dump. [\#76](https://github.com/swift-nav/piksi_tools/pull/76)
- Add scripts for generation of core dumps. [\#70](https://github.com/swift-nav/piksi_tools/pull/70)

## [v0.22](https://github.com/swift-nav/piksi_tools/tree/v0.22) (2015-06-19)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.21...v0.22)

**Merged pull requests:**

- New mavlink bridge [\#74](https://github.com/swift-nav/piksi_tools/pull/74)
- Fix message handling [\#72](https://github.com/swift-nav/piksi_tools/pull/72)
- Generate settings as JSON file [\#71](https://github.com/swift-nav/piksi_tools/pull/71)
- Handler starts the link [\#67](https://github.com/swift-nav/piksi_tools/pull/67)
- add -o command line arg [\#58](https://github.com/swift-nav/piksi_tools/pull/58)

## [v0.21](https://github.com/swift-nav/piksi_tools/tree/v0.21) (2015-06-15)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.21-rc0...v0.21)

**Merged pull requests:**

- update initial variance default values in float KF [\#64](https://github.com/swift-nav/piksi_tools/pull/64)

## [v0.21-rc0](https://github.com/swift-nav/piksi_tools/tree/v0.21-rc0) (2015-06-12)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.20...v0.21-rc0)

## [v0.20](https://github.com/swift-nav/piksi_tools/tree/v0.20) (2015-06-12)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.19...v0.20)

## [v0.19](https://github.com/swift-nav/piksi_tools/tree/v0.19) (2015-06-11)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.18...v0.19)

## [v0.18](https://github.com/swift-nav/piksi_tools/tree/v0.18) (2015-06-11)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.17...v0.18)

**Merged pull requests:**

- Better versioning [\#60](https://github.com/swift-nav/piksi_tools/pull/60)
- add reset button to system monitor view [\#59](https://github.com/swift-nav/piksi_tools/pull/59)
- Versioned bootloader [\#57](https://github.com/swift-nav/piksi_tools/pull/57)
- Move off console's version to piksi\_tools version [\#56](https://github.com/swift-nav/piksi_tools/pull/56)

## [v0.17](https://github.com/swift-nav/piksi_tools/tree/v0.17) (2015-06-08)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.16.1...v0.17)

**Closed issues:**

- Build console to work in windows XP [\#46](https://github.com/swift-nav/piksi_tools/issues/46)

**Merged pull requests:**

- Bring versioning back in [\#55](https://github.com/swift-nav/piksi_tools/pull/55)
- New sbp with new bootloader messages [\#52](https://github.com/swift-nav/piksi_tools/pull/52)

## [v0.16.1](https://github.com/swift-nav/piksi_tools/tree/v0.16.1) (2015-05-16)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.16...v0.16.1)

**Fixed bugs:**

- Update wiki to reflect piksi\_firmware/scripts move to piksi\_tools [\#40](https://github.com/swift-nav/piksi_tools/issues/40)

**Closed issues:**

- Need headers on any CSV /Rinex files generated by console [\#9](https://github.com/swift-nav/piksi_tools/issues/9)

**Merged pull requests:**

- don't clear the settings when you press the read button [\#50](https://github.com/swift-nav/piksi_tools/pull/50)
- add headers to csv files auto logged by console [\#44](https://github.com/swift-nav/piksi_tools/pull/44)
- Inject tags into logs [\#43](https://github.com/swift-nav/piksi_tools/pull/43)
- Bring in setup.sh for piksi\_tools [\#41](https://github.com/swift-nav/piksi_tools/pull/41)

## [v0.16](https://github.com/swift-nav/piksi_tools/tree/v0.16) (2015-05-06)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.13...v0.16)

**Closed issues:**

- v0.16 release [\#37](https://github.com/swift-nav/piksi_tools/issues/37)

## [v0.13](https://github.com/swift-nav/piksi_tools/tree/v0.13) (2015-05-06)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.12...v0.13)

**Merged pull requests:**

- Have print\_device\_details wait before requesting settings from Piksi. [\#36](https://github.com/swift-nav/piksi_tools/pull/36)
- Fire the read\_button on the settings view in print\_device\_details.py [\#35](https://github.com/swift-nav/piksi_tools/pull/35)
- Update README.rst [\#32](https://github.com/swift-nav/piksi_tools/pull/32)

## [v0.12](https://github.com/swift-nav/piksi_tools/tree/v0.12) (2015-04-24)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.11...v0.12)

**Merged pull requests:**

- Add an append file option to serial\_link.py [\#31](https://github.com/swift-nav/piksi_tools/pull/31)
- Bring pyinstaller makefile over [\#30](https://github.com/swift-nav/piksi_tools/pull/30)
- Support both old and new ephemeris IDs [\#29](https://github.com/swift-nav/piksi_tools/pull/29)

## [v0.11](https://github.com/swift-nav/piksi_tools/tree/v0.11) (2015-04-17)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.10...v0.11)

**Merged pull requests:**

- Pickle. It was a thing [\#25](https://github.com/swift-nav/piksi_tools/pull/25)

## [v0.10](https://github.com/swift-nav/piksi_tools/tree/v0.10) (2015-04-17)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.9...v0.10)

## [v0.9](https://github.com/swift-nav/piksi_tools/tree/v0.9) (2015-04-17)
[Full Changelog](https://github.com/swift-nav/piksi_tools/compare/v0.2...v0.9)

**Implemented enhancements:**

- Add 'system\_monitor.watchdog' setting to enable/disable watchdog timer. [\#22](https://github.com/swift-nav/piksi_tools/pull/22)
- Bring in ext\_events console support from piksi\_firmware [\#17](https://github.com/swift-nav/piksi_tools/pull/17)

**Closed issues:**

- Move the console into piksi\_tools.console [\#10](https://github.com/swift-nav/piksi_tools/issues/10)

**Merged pull requests:**

- Support logging JSON and pickle at the same time [\#23](https://github.com/swift-nav/piksi_tools/pull/23)
- Add intelhex to requirements, needed by bootload.py [\#20](https://github.com/swift-nav/piksi_tools/pull/20)
- Bring over the watchdog [\#18](https://github.com/swift-nav/piksi_tools/pull/18)
- Serial cleanup and console relocation [\#13](https://github.com/swift-nav/piksi_tools/pull/13)
- add argument to settings view [\#8](https://github.com/swift-nav/piksi_tools/pull/8)
- Serial leaning [\#2](https://github.com/swift-nav/piksi_tools/pull/2)

## [v0.2](https://github.com/swift-nav/piksi_tools/tree/v0.2) (2015-04-01)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*